# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: job.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import comment_pb2 as comment__pb2
from . import depend_pb2 as depend__pb2
from . import limit_pb2 as limit__pb2
from . import renderPartition_pb2 as renderPartition__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tjob.proto\x12\x03job\x1a\rcomment.proto\x1a\x0c\x64\x65pend.proto\x1a\x0blimit.proto\x1a\x15renderPartition.proto\"\xad\x01\n\x19\x46rameStateDisplayOverride\x12\x1e\n\x05state\x18\x01 \x01(\x0e\x32\x0f.job.FrameState\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x31\n\x05\x63olor\x18\x03 \x01(\x0b\x32\".job.FrameStateDisplayOverride.RGB\x1a/\n\x03RGB\x12\x0b\n\x03red\x18\x01 \x01(\x05\x12\r\n\x05green\x18\x02 \x01(\x05\x12\x0c\n\x04\x62lue\x18\x03 \x01(\x05\"Q\n\x1c\x46rameStateDisplayOverrideSeq\x12\x31\n\toverrides\x18\x01 \x03(\x0b\x32\x1e.job.FrameStateDisplayOverride\"\xc5\x04\n\x05\x46rame\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nlayer_name\x18\x03 \x01(\t\x12\x0e\n\x06number\x18\x04 \x01(\x05\x12\x1e\n\x05state\x18\x05 \x01(\x0e\x32\x0f.job.FrameState\x12\x13\n\x0bretry_count\x18\x06 \x01(\x05\x12\x13\n\x0b\x65xit_status\x18\x07 \x01(\x05\x12\x16\n\x0e\x64ispatch_order\x18\x08 \x01(\x05\x12\x12\n\nstart_time\x18\t \x01(\x05\x12\x11\n\tstop_time\x18\n \x01(\x05\x12\x0f\n\x07max_rss\x18\x0b \x01(\x03\x12\x13\n\x0bused_memory\x18\x0c \x01(\x03\x12\x17\n\x0freserved_memory\x18\r \x01(\x03\x12\x1b\n\x13reserved_gpu_memory\x18\x0e \x01(\x03\x12\x15\n\rlast_resource\x18\x0f \x01(\t\x12.\n\x10\x63heckpoint_state\x18\x10 \x01(\x0e\x32\x14.job.CheckpointState\x12\x18\n\x10\x63heckpoint_count\x18\x11 \x01(\x05\x12\x17\n\x0ftotal_core_time\x18\x12 \x01(\x05\x12\x10\n\x08llu_time\x18\x13 \x01(\x05\x12\x16\n\x0etotal_gpu_time\x18\x14 \x01(\x05\x12\x16\n\x0emax_gpu_memory\x18\x15 \x01(\x03\x12\x17\n\x0fused_gpu_memory\x18\x16 \x01(\x03\x12\x44\n\x1c\x66rame_state_display_override\x18\x17 \x01(\x0b\x32\x1e.job.FrameStateDisplayOverride\"\x9a\x02\n\x13\x46rameSearchCriteria\x12\x0b\n\x03ids\x18\x01 \x03(\t\x12\x0e\n\x06\x66rames\x18\x02 \x03(\t\x12\x0e\n\x06layers\x18\x03 \x03(\t\x12\"\n\x06states\x18\x04 \x01(\x0b\x32\x12.job.FrameStateSeq\x12\x13\n\x0b\x66rame_range\x18\x05 \x01(\t\x12\x14\n\x0cmemory_range\x18\x06 \x01(\t\x12\x16\n\x0e\x64uration_range\x18\x07 \x01(\t\x12\x0c\n\x04page\x18\x08 \x01(\x05\x12\r\n\x05limit\x18\t \x01(\x05\x12\x13\n\x0b\x63hange_date\x18\n \x01(\x05\x12\x13\n\x0bmax_results\x18\x0b \x01(\x05\x12\x0e\n\x06offset\x18\x0c \x01(\x05\x12\x18\n\x10include_finished\x18\r \x01(\x08\"&\n\x08\x46rameSeq\x12\x1a\n\x06\x66rames\x18\x01 \x03(\x0b\x32\n.job.Frame\"6\n\rFrameStateSeq\x12%\n\x0c\x66rame_states\x18\x01 \x03(\x0e\x32\x0f.job.FrameState\"\xd1\x02\n\x0cUpdatedFrame\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1e\n\x05state\x18\x02 \x01(\x0e\x32\x0f.job.FrameState\x12\x13\n\x0bretry_count\x18\x03 \x01(\x05\x12\x13\n\x0b\x65xit_status\x18\x04 \x01(\x05\x12\x12\n\nstart_time\x18\x05 \x01(\x05\x12\x11\n\tstop_time\x18\x06 \x01(\x05\x12\x0f\n\x07max_rss\x18\x07 \x01(\x03\x12\x13\n\x0bused_memory\x18\x08 \x01(\x03\x12\x15\n\rlast_resource\x18\t \x01(\t\x12\x10\n\x08llu_time\x18\n \x01(\x05\x12\x16\n\x0emax_gpu_memory\x18\x0b \x01(\x03\x12\x17\n\x0fused_gpu_memory\x18\x0c \x01(\x03\x12\x44\n\x1c\x66rame_state_display_override\x18\r \x01(\x0b\x32\x1e.job.FrameStateDisplayOverride\"<\n\x0fUpdatedFrameSeq\x12)\n\x0eupdated_frames\x18\x01 \x03(\x0b\x32\x11.job.UpdatedFrame\"z\n\x17UpdatedFrameCheckResult\x12\x1c\n\x05state\x18\x01 \x01(\x0e\x32\r.job.JobState\x12\x13\n\x0bserver_time\x18\x02 \x01(\x05\x12,\n\x0eupdated_frames\x18\x03 \x01(\x0b\x32\x14.job.UpdatedFrameSeq\"\xdf\x02\n\x05Group\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\ndepartment\x18\x03 \x01(\t\x12\x1c\n\x14\x64\x65\x66\x61ult_job_priority\x18\x04 \x01(\x05\x12\x1d\n\x15\x64\x65\x66\x61ult_job_min_cores\x18\x05 \x01(\x02\x12\x1d\n\x15\x64\x65\x66\x61ult_job_max_cores\x18\x06 \x01(\x02\x12\x11\n\tmin_cores\x18\x07 \x01(\x02\x12\x11\n\tmax_cores\x18\x08 \x01(\x02\x12\r\n\x05level\x18\t \x01(\x05\x12\x11\n\tparent_id\x18\n \x01(\t\x12$\n\x0bgroup_stats\x18\x0b \x01(\x0b\x32\x0f.job.GroupStats\x12\x1c\n\x14\x64\x65\x66\x61ult_job_min_gpus\x18\x0c \x01(\x02\x12\x1c\n\x14\x64\x65\x66\x61ult_job_max_gpus\x18\r \x01(\x02\x12\x10\n\x08min_gpus\x18\x0e \x01(\x02\x12\x10\n\x08max_gpus\x18\x0f \x01(\x02\"&\n\x08GroupSeq\x12\x1a\n\x06groups\x18\x01 \x03(\x0b\x32\n.job.Group\"\xad\x01\n\nGroupStats\x12\x16\n\x0erunning_frames\x18\x01 \x01(\x05\x12\x13\n\x0b\x64\x65\x61\x64_frames\x18\x02 \x01(\x05\x12\x15\n\rdepend_frames\x18\x03 \x01(\x05\x12\x16\n\x0ewaiting_frames\x18\x04 \x01(\x05\x12\x14\n\x0cpending_jobs\x18\x05 \x01(\x05\x12\x16\n\x0ereserved_cores\x18\x06 \x01(\x02\x12\x15\n\rreserved_gpus\x18\x07 \x01(\x02\"\xb5\x03\n\x03Job\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1c\n\x05state\x18\x02 \x01(\x0e\x32\r.job.JobState\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04shot\x18\x04 \x01(\t\x12\x0c\n\x04show\x18\x05 \x01(\t\x12\x0c\n\x04user\x18\x06 \x01(\t\x12\r\n\x05group\x18\x07 \x01(\t\x12\x10\n\x08\x66\x61\x63ility\x18\x08 \x01(\t\x12\n\n\x02os\x18\t \x01(\t\x12\r\n\x03uid\x18\n \x01(\x05H\x00\x12\x10\n\x08priority\x18\x0b \x01(\x05\x12\x11\n\tmin_cores\x18\x0c \x01(\x02\x12\x11\n\tmax_cores\x18\r \x01(\x02\x12\x0f\n\x07log_dir\x18\x0e \x01(\t\x12\x11\n\tis_paused\x18\x0f \x01(\x08\x12\x13\n\x0bhas_comment\x18\x10 \x01(\x08\x12\x10\n\x08\x61uto_eat\x18\x11 \x01(\x08\x12\x12\n\nstart_time\x18\x12 \x01(\x05\x12\x11\n\tstop_time\x18\x13 \x01(\x05\x12 \n\tjob_stats\x18\x14 \x01(\x0b\x32\r.job.JobStats\x12\x10\n\x08min_gpus\x18\x15 \x01(\x02\x12\x10\n\x08max_gpus\x18\x16 \x01(\x02\x12\x10\n\x08loki_url\x18\x17 \x01(\tB\x0e\n\x0cuid_optional\"\x94\x01\n\x11JobSearchCriteria\x12\x0b\n\x03ids\x18\x01 \x03(\t\x12\x0c\n\x04jobs\x18\x02 \x03(\t\x12\r\n\x05regex\x18\x03 \x03(\t\x12\x0e\n\x06substr\x18\x04 \x03(\t\x12\r\n\x05users\x18\x05 \x03(\t\x12\r\n\x05shots\x18\x06 \x03(\t\x12\r\n\x05shows\x18\x07 \x03(\t\x12\x18\n\x10include_finished\x18\x08 \x01(\x08\" \n\x06JobSeq\x12\x16\n\x04jobs\x18\x01 \x03(\x0b\x32\x08.job.Job\"\xe2\x04\n\x08JobStats\x12\x14\n\x0ctotal_layers\x18\x01 \x01(\x05\x12\x14\n\x0ctotal_frames\x18\x02 \x01(\x05\x12\x16\n\x0ewaiting_frames\x18\x03 \x01(\x05\x12\x16\n\x0erunning_frames\x18\x04 \x01(\x05\x12\x13\n\x0b\x64\x65\x61\x64_frames\x18\x05 \x01(\x05\x12\x14\n\x0c\x65\x61ten_frames\x18\x06 \x01(\x05\x12\x15\n\rdepend_frames\x18\x07 \x01(\x05\x12\x18\n\x10succeeded_frames\x18\x08 \x01(\x05\x12\x16\n\x0epending_frames\x18\t \x01(\x05\x12\x15\n\ravg_frame_sec\x18\n \x01(\x05\x12\x16\n\x0ehigh_frame_sec\x18\x0b \x01(\x05\x12\x14\n\x0c\x61vg_core_sec\x18\x0c \x01(\x05\x12\x1c\n\x14rendered_frame_count\x18\r \x01(\x03\x12\x1a\n\x12\x66\x61iled_frame_count\x18\x0e \x01(\x03\x12\x1a\n\x12remaining_core_sec\x18\x0f \x01(\x03\x12\x16\n\x0etotal_core_sec\x18\x10 \x01(\x03\x12\x19\n\x11rendered_core_sec\x18\x11 \x01(\x03\x12\x17\n\x0f\x66\x61iled_core_sec\x18\x12 \x01(\x03\x12\x0f\n\x07max_rss\x18\x13 \x01(\x03\x12\x16\n\x0ereserved_cores\x18\x14 \x01(\x02\x12\x15\n\rtotal_gpu_sec\x18\x15 \x01(\x03\x12\x18\n\x10rendered_gpu_sec\x18\x16 \x01(\x03\x12\x16\n\x0e\x66\x61iled_gpu_sec\x18\x17 \x01(\x03\x12\x15\n\rreserved_gpus\x18\x18 \x01(\x02\x12\x16\n\x0emax_gpu_memory\x18\x19 \x01(\x03\"\xc9\x03\n\x05Layer\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05range\x18\x03 \x01(\t\x12\x0c\n\x04tags\x18\x04 \x03(\t\x12\x11\n\tmin_cores\x18\x05 \x01(\x02\x12\x11\n\tmax_cores\x18\x06 \x01(\x02\x12\x15\n\ris_threadable\x18\x07 \x01(\x08\x12\x12\n\nmin_memory\x18\x08 \x01(\x03\x12\x16\n\x0emin_gpu_memory\x18\t \x01(\x03\x12\x12\n\nchunk_size\x18\n \x01(\x05\x12\x16\n\x0e\x64ispatch_order\x18\x0b \x01(\x05\x12\x1c\n\x04type\x18\x0c \x01(\x0e\x32\x0e.job.LayerType\x12\x10\n\x08services\x18\r \x03(\t\x12 \n\x18memory_optimizer_enabled\x18\x0e \x01(\x08\x12$\n\x0blayer_stats\x18\x0f \x01(\x0b\x32\x0f.job.LayerStats\x12\x11\n\tparent_id\x18\x10 \x01(\t\x12\x0e\n\x06limits\x18\x11 \x03(\t\x12\x0f\n\x07timeout\x18\x12 \x01(\x05\x12\x13\n\x0btimeout_llu\x18\x13 \x01(\x05\x12\x10\n\x08min_gpus\x18\x14 \x01(\x02\x12\x10\n\x08max_gpus\x18\x15 \x01(\x02\x12\x0f\n\x07\x63ommand\x18\x16 \x01(\t\"&\n\x08LayerSeq\x12\x1a\n\x06layers\x18\x01 \x03(\x0b\x32\n.job.Layer\"\xe5\x04\n\nLayerStats\x12\x14\n\x0ctotal_frames\x18\x01 \x01(\x05\x12\x16\n\x0ewaiting_frames\x18\x02 \x01(\x05\x12\x16\n\x0erunning_frames\x18\x03 \x01(\x05\x12\x13\n\x0b\x64\x65\x61\x64_frames\x18\x04 \x01(\x05\x12\x14\n\x0c\x65\x61ten_frames\x18\x05 \x01(\x05\x12\x15\n\rdepend_frames\x18\x06 \x01(\x05\x12\x18\n\x10succeeded_frames\x18\x07 \x01(\x05\x12\x16\n\x0epending_frames\x18\x08 \x01(\x05\x12\x15\n\ravg_frame_sec\x18\t \x01(\x05\x12\x15\n\rlow_frame_sec\x18\n \x01(\x05\x12\x16\n\x0ehigh_frame_sec\x18\x0b \x01(\x05\x12\x14\n\x0c\x61vg_core_sec\x18\x0c \x01(\x05\x12\x1c\n\x14rendered_frame_count\x18\r \x01(\x03\x12\x1a\n\x12\x66\x61iled_frame_count\x18\x0e \x01(\x03\x12\x1a\n\x12remaining_core_sec\x18\x0f \x01(\x03\x12\x16\n\x0etotal_core_sec\x18\x10 \x01(\x03\x12\x19\n\x11rendered_core_sec\x18\x11 \x01(\x03\x12\x17\n\x0f\x66\x61iled_core_sec\x18\x12 \x01(\x03\x12\x0f\n\x07max_rss\x18\x13 \x01(\x03\x12\x16\n\x0ereserved_cores\x18\x14 \x01(\x02\x12\x15\n\rtotal_gpu_sec\x18\x15 \x01(\x03\x12\x18\n\x10rendered_gpu_sec\x18\x16 \x01(\x03\x12\x16\n\x0e\x66\x61iled_gpu_sec\x18\x17 \x01(\x03\x12\x15\n\rreserved_gpus\x18\x18 \x01(\x02\x12\x16\n\x0emax_gpu_memory\x18\x19 \x01(\x03\"\xa1\x03\n\x0bNestedGroup\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\ndepartment\x18\x03 \x01(\t\x12\x1c\n\x14\x64\x65\x66\x61ult_job_priority\x18\x04 \x01(\x05\x12\x1d\n\x15\x64\x65\x66\x61ult_job_min_cores\x18\x05 \x01(\x02\x12\x1d\n\x15\x64\x65\x66\x61ult_job_max_cores\x18\x06 \x01(\x02\x12\x11\n\tmin_cores\x18\x07 \x01(\x02\x12\x11\n\tmax_cores\x18\x08 \x01(\x02\x12\r\n\x05level\x18\t \x01(\x05\x12 \n\x06parent\x18\n \x01(\x0b\x32\x10.job.NestedGroup\x12#\n\x06groups\x18\x0b \x01(\x0b\x32\x13.job.NestedGroupSeq\x12\x0c\n\x04jobs\x18\x0c \x03(\t\x12\x1e\n\x05stats\x18\r \x01(\x0b\x32\x0f.job.GroupStats\x12\x1c\n\x14\x64\x65\x66\x61ult_job_min_gpus\x18\x0e \x01(\x02\x12\x1c\n\x14\x64\x65\x66\x61ult_job_max_gpus\x18\x0f \x01(\x02\x12\x10\n\x08min_gpus\x18\x10 \x01(\x02\x12\x10\n\x08max_gpus\x18\x11 \x01(\x02\"9\n\x0eNestedGroupSeq\x12\'\n\rnested_groups\x18\x01 \x03(\x0b\x32\x10.job.NestedGroup\"\xc7\x03\n\tNestedJob\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1c\n\x05state\x18\x02 \x01(\x0e\x32\r.job.JobState\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04shot\x18\x04 \x01(\t\x12\x0c\n\x04show\x18\x05 \x01(\t\x12\x0c\n\x04user\x18\x06 \x01(\t\x12\r\n\x05group\x18\x07 \x01(\t\x12\x10\n\x08\x66\x61\x63ility\x18\x08 \x01(\t\x12\n\n\x02os\x18\t \x01(\t\x12\r\n\x03uid\x18\n \x01(\x05H\x00\x12\x10\n\x08priority\x18\x0b \x01(\x05\x12\x11\n\tmin_cores\x18\x0c \x01(\x02\x12\x11\n\tmax_cores\x18\r \x01(\x02\x12\x0f\n\x07log_dir\x18\x0e \x01(\t\x12\x11\n\tis_paused\x18\x0f \x01(\x08\x12\x13\n\x0bhas_comment\x18\x10 \x01(\x08\x12\x10\n\x08\x61uto_eat\x18\x11 \x01(\x08\x12\x12\n\nstart_time\x18\x12 \x01(\x05\x12\x11\n\tstop_time\x18\x13 \x01(\x05\x12 \n\x06parent\x18\x14 \x01(\x0b\x32\x10.job.NestedGroup\x12\x1c\n\x05stats\x18\x15 \x01(\x0b\x32\r.job.JobStats\x12\x10\n\x08min_gpus\x18\x16 \x01(\x02\x12\x10\n\x08max_gpus\x18\x17 \x01(\x02\x42\x0e\n\x0cuid_optional\"\xbd\x01\n\x1e\x46rameAddRenderPartitionRequest\x12\x19\n\x05\x66rame\x18\x01 \x01(\x0b\x32\n.job.Frame\x12\x0c\n\x04host\x18\x02 \x01(\t\x12\x0f\n\x07threads\x18\x03 \x01(\x05\x12\x11\n\tmax_cores\x18\x04 \x01(\x05\x12\x12\n\nmax_memory\x18\x05 \x01(\x03\x12\x16\n\x0emax_gpu_memory\x18\x06 \x01(\x03\x12\x10\n\x08username\x18\x07 \x01(\t\x12\x10\n\x08max_gpus\x18\x08 \x01(\x05\"]\n\x1f\x46rameAddRenderPartitionResponse\x12:\n\x10render_partition\x18\x01 \x01(\x0b\x32 .renderPartition.RenderPartition\"e\n#FrameCreateDependencyOnFrameRequest\x12\x19\n\x05\x66rame\x18\x01 \x01(\x0b\x32\n.job.Frame\x12#\n\x0f\x64\x65pend_on_frame\x18\x02 \x01(\x0b\x32\n.job.Frame\"F\n$FrameCreateDependencyOnFrameResponse\x12\x1e\n\x06\x64\x65pend\x18\x01 \x01(\x0b\x32\x0e.depend.Depend\"U\n!FrameCreateDependencyOnJobRequest\x12\x19\n\x05\x66rame\x18\x01 \x01(\x0b\x32\n.job.Frame\x12\x15\n\x03job\x18\x02 \x01(\x0b\x32\x08.job.Job\"D\n\"FrameCreateDependencyOnJobResponse\x12\x1e\n\x06\x64\x65pend\x18\x01 \x01(\x0b\x32\x0e.depend.Depend\"[\n#FrameCreateDependencyOnLayerRequest\x12\x19\n\x05\x66rame\x18\x01 \x01(\x0b\x32\n.job.Frame\x12\x19\n\x05layer\x18\x02 \x01(\x0b\x32\n.job.Layer\"F\n$FrameCreateDependencyOnLayerResponse\x12\x1e\n\x06\x64\x65pend\x18\x01 \x01(\x0b\x32\x0e.depend.Depend\"Z\n\x17\x46rameDropDependsRequest\x12\x19\n\x05\x66rame\x18\x01 \x01(\x0b\x32\n.job.Frame\x12$\n\x06target\x18\x02 \x01(\x0e\x32\x14.depend.DependTarget\"\x1a\n\x18\x46rameDropDependsResponse\",\n\x0f\x46rameEatRequest\x12\x19\n\x05\x66rame\x18\x01 \x01(\x0b\x32\n.job.Frame\"\x12\n\x10\x46rameEatResponse\"B\n\x15\x46rameFindFrameRequest\x12\x0b\n\x03job\x18\x01 \x01(\t\x12\r\n\x05layer\x18\x02 \x01(\t\x12\r\n\x05\x66rame\x18\x03 \x01(\x05\"3\n\x16\x46rameFindFrameResponse\x12\x19\n\x05\x66rame\x18\x01 \x01(\x0b\x32\n.job.Frame\"\"\n\x14\x46rameGetFrameRequest\x12\n\n\x02id\x18\x01 \x01(\t\"2\n\x15\x46rameGetFrameResponse\x12\x19\n\x05\x66rame\x18\x01 \x01(\x0b\x32\n.job.Frame\"I\n\x15\x46rameGetFramesRequest\x12\x0b\n\x03job\x18\x01 \x01(\t\x12#\n\x01r\x18\x02 \x01(\x0b\x32\x18.job.FrameSearchCriteria\"7\n\x16\x46rameGetFramesResponse\x12\x1d\n\x06\x66rames\x18\x01 \x01(\x0b\x32\r.job.FrameSeq\"=\n FrameGetWhatDependsOnThisRequest\x12\x19\n\x05\x66rame\x18\x01 \x01(\x0b\x32\n.job.Frame\"G\n!FrameGetWhatDependsOnThisResponse\x12\"\n\x07\x64\x65pends\x18\x01 \x01(\x0b\x32\x11.depend.DependSeq\"=\n FrameGetWhatThisDependsOnRequest\x12\x19\n\x05\x66rame\x18\x01 \x01(\x0b\x32\n.job.Frame\"G\n!FrameGetWhatThisDependsOnResponse\x12\"\n\x07\x64\x65pends\x18\x01 \x01(\x0b\x32\x11.depend.DependSeq\"o\n\x10\x46rameKillRequest\x12\x19\n\x05\x66rame\x18\x01 \x01(\x0b\x32\n.job.Frame\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x0b\n\x03pid\x18\x03 \x01(\t\x12\x11\n\thost_kill\x18\x04 \x01(\t\x12\x0e\n\x06reason\x18\x05 \x01(\t\"\x13\n\x11\x46rameKillResponse\"5\n\x18\x46rameMarkAsDependRequest\x12\x19\n\x05\x66rame\x18\x01 \x01(\x0b\x32\n.job.Frame\"\x1b\n\x19\x46rameMarkAsDependResponse\"6\n\x19\x46rameMarkAsWaitingRequest\x12\x19\n\x05\x66rame\x18\x01 \x01(\x0b\x32\n.job.Frame\"\x1c\n\x1a\x46rameMarkAsWaitingResponse\".\n\x11\x46rameRetryRequest\x12\x19\n\x05\x66rame\x18\x01 \x01(\x0b\x32\n.job.Frame\"\x14\n\x12\x46rameRetryResponse\"`\n\x1e\x46rameSetCheckpointStateRequest\x12\x19\n\x05\x66rame\x18\x01 \x01(\x0b\x32\n.job.Frame\x12#\n\x05state\x18\x02 \x01(\x0e\x32\x14.job.CheckpointState\"!\n\x1f\x46rameSetCheckpointStateResponse\"E\n\x1aGroupCreateSubGroupRequest\x12\x19\n\x05group\x18\x01 \x01(\x0b\x32\n.job.Group\x12\x0c\n\x04name\x18\x02 \x01(\t\"8\n\x1bGroupCreateSubGroupResponse\x12\x19\n\x05group\x18\x01 \x01(\x0b\x32\n.job.Group\"/\n\x12GroupDeleteRequest\x12\x19\n\x05group\x18\x01 \x01(\x0b\x32\n.job.Group\"\x15\n\x13GroupDeleteResponse\"3\n\x15GroupFindGroupRequest\x12\x0c\n\x04show\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"3\n\x16GroupFindGroupResponse\x12\x19\n\x05group\x18\x01 \x01(\x0b\x32\n.job.Group\"\"\n\x14GroupGetGroupRequest\x12\n\n\x02id\x18\x01 \x01(\t\"2\n\x15GroupGetGroupResponse\x12\x19\n\x05group\x18\x01 \x01(\x0b\x32\n.job.Group\"2\n\x15GroupGetGroupsRequest\x12\x19\n\x05group\x18\x01 \x01(\x0b\x32\n.job.Group\"7\n\x16GroupGetGroupsResponse\x12\x1d\n\x06groups\x18\x01 \x01(\x0b\x32\r.job.GroupSeq\"0\n\x13GroupGetJobsRequest\x12\x19\n\x05group\x18\x01 \x01(\x0b\x32\n.job.Group\"1\n\x14GroupGetJobsResponse\x12\x19\n\x04jobs\x18\x01 \x01(\x0b\x32\x0b.job.JobSeq\"V\n\x1aGroupReparentGroupsRequest\x12\x19\n\x05group\x18\x01 \x01(\x0b\x32\n.job.Group\x12\x1d\n\x06groups\x18\x02 \x01(\x0b\x32\r.job.GroupSeq\"\x1d\n\x1bGroupReparentGroupsResponse\"P\n\x18GroupReparentJobsRequest\x12\x19\n\x05group\x18\x01 \x01(\x0b\x32\n.job.Group\x12\x19\n\x04jobs\x18\x02 \x01(\x0b\x32\x0b.job.JobSeq\"\x1b\n\x19GroupReparentJobsResponse\"M\n\x1dGroupSetDefJobMaxCoresRequest\x12\x19\n\x05group\x18\x01 \x01(\x0b\x32\n.job.Group\x12\x11\n\tmax_cores\x18\x02 \x01(\x02\" \n\x1eGroupSetDefJobMaxCoresResponse\"M\n\x1dGroupSetDefJobMinCoresRequest\x12\x19\n\x05group\x18\x01 \x01(\x0b\x32\n.job.Group\x12\x11\n\tmin_cores\x18\x02 \x01(\x02\" \n\x1eGroupSetDefJobMinCoresResponse\"K\n\x1cGroupSetDefJobMaxGpusRequest\x12\x19\n\x05group\x18\x01 \x01(\x0b\x32\n.job.Group\x12\x10\n\x08max_gpus\x18\x02 \x01(\x05\"\x1f\n\x1dGroupSetDefJobMaxGpusResponse\"K\n\x1cGroupSetDefJobMinGpusRequest\x12\x19\n\x05group\x18\x01 \x01(\x0b\x32\n.job.Group\x12\x10\n\x08min_gpus\x18\x02 \x01(\x05\"\x1f\n\x1dGroupSetDefJobMinGpusResponse\"L\n\x1dGroupSetDefJobPriorityRequest\x12\x19\n\x05group\x18\x01 \x01(\x0b\x32\n.job.Group\x12\x10\n\x08priority\x18\x02 \x01(\x05\" \n\x1eGroupSetDefJobPriorityResponse\">\n\x13GroupSetDeptRequest\x12\x19\n\x05group\x18\x01 \x01(\x0b\x32\n.job.Group\x12\x0c\n\x04\x64\x65pt\x18\x02 \x01(\t\"\x16\n\x14GroupSetDeptResponse\"S\n\x14GroupSetGroupRequest\x12\x19\n\x05group\x18\x01 \x01(\x0b\x32\n.job.Group\x12 \n\x0cparent_group\x18\x02 \x01(\x0b\x32\n.job.Group\"\x17\n\x15GroupSetGroupResponse\"G\n\x17GroupSetMaxCoresRequest\x12\x19\n\x05group\x18\x01 \x01(\x0b\x32\n.job.Group\x12\x11\n\tmax_cores\x18\x02 \x01(\x02\"\x1a\n\x18GroupSetMaxCoresResponse\"G\n\x17GroupSetMinCoresRequest\x12\x19\n\x05group\x18\x01 \x01(\x0b\x32\n.job.Group\x12\x11\n\tmin_cores\x18\x02 \x01(\x02\"\x1a\n\x18GroupSetMinCoresResponse\"E\n\x16GroupSetMaxGpusRequest\x12\x19\n\x05group\x18\x01 \x01(\x0b\x32\n.job.Group\x12\x10\n\x08max_gpus\x18\x02 \x01(\x05\"\x19\n\x17GroupSetMaxGpusResponse\"E\n\x16GroupSetMinGpusRequest\x12\x19\n\x05group\x18\x01 \x01(\x0b\x32\n.job.Group\x12\x10\n\x08min_gpus\x18\x02 \x01(\x05\"\x19\n\x17GroupSetMinGpusResponse\">\n\x13GroupSetNameRequest\x12\x19\n\x05group\x18\x01 \x01(\x0b\x32\n.job.Group\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x16\n\x14GroupSetNameResponse\"T\n\x14JobAddCommentRequest\x12\x15\n\x03job\x18\x01 \x01(\x0b\x32\x08.job.Job\x12%\n\x0bnew_comment\x18\x02 \x01(\x0b\x32\x10.comment.Comment\"\x17\n\x15JobAddCommentResponse\"\xb2\x01\n\x17JobAddRenderPartRequest\x12\x15\n\x03job\x18\x01 \x01(\x0b\x32\x08.job.Job\x12\x0c\n\x04host\x18\x02 \x01(\t\x12\x0f\n\x07threads\x18\x03 \x01(\x05\x12\x11\n\tmax_cores\x18\x04 \x01(\x05\x12\x12\n\nmax_memory\x18\x05 \x01(\x03\x12\x16\n\x0emax_gpu_memory\x18\x06 \x01(\x03\x12\x10\n\x08username\x18\x07 \x01(\t\x12\x10\n\x08max_gpus\x18\x08 \x01(\x05\"V\n\x18JobAddRenderPartResponse\x12:\n\x10render_partition\x18\x01 \x01(\x0b\x32 .renderPartition.RenderPartition\"D\n\x17JobAddSubscriberRequest\x12\x15\n\x03job\x18\x01 \x01(\x0b\x32\x08.job.Job\x12\x12\n\nsubscriber\x18\x02 \x01(\t\"\x1a\n\x18JobAddSubscriberResponse\"U\n!JobCreateDependencyOnFrameRequest\x12\x15\n\x03job\x18\x01 \x01(\x0b\x32\x08.job.Job\x12\x19\n\x05\x66rame\x18\x02 \x01(\x0b\x32\n.job.Frame\"D\n\"JobCreateDependencyOnFrameResponse\x12\x1e\n\x06\x64\x65pend\x18\x01 \x01(\x0b\x32\x0e.depend.Depend\"R\n\x1fJobCreateDependencyOnJobRequest\x12\x15\n\x03job\x18\x01 \x01(\x0b\x32\x08.job.Job\x12\x18\n\x06on_job\x18\x02 \x01(\x0b\x32\x08.job.Job\"B\n JobCreateDependencyOnJobResponse\x12\x1e\n\x06\x64\x65pend\x18\x01 \x01(\x0b\x32\x0e.depend.Depend\"U\n!JobCreateDependencyOnLayerRequest\x12\x15\n\x03job\x18\x01 \x01(\x0b\x32\x08.job.Job\x12\x19\n\x05layer\x18\x02 \x01(\x0b\x32\n.job.Layer\"D\n\"JobCreateDependencyOnLayerResponse\x12\x1e\n\x06\x64\x65pend\x18\x01 \x01(\x0b\x32\x0e.depend.Depend\"T\n\x15JobDropDependsRequest\x12\x15\n\x03job\x18\x01 \x01(\x0b\x32\x08.job.Job\x12$\n\x06target\x18\x02 \x01(\x0e\x32\x14.depend.DependTarget\"\x18\n\x16JobDropDependsResponse\"S\n\x13JobEatFramesRequest\x12\x15\n\x03job\x18\x01 \x01(\x0b\x32\x08.job.Job\x12%\n\x03req\x18\x02 \x01(\x0b\x32\x18.job.FrameSearchCriteria\"\x16\n\x14JobEatFramesResponse\"!\n\x11JobFindJobRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"+\n\x12JobFindJobResponse\x12\x15\n\x03job\x18\x01 \x01(\x0b\x32\x08.job.Job\".\n\x15JobGetCommentsRequest\x12\x15\n\x03job\x18\x01 \x01(\x0b\x32\x08.job.Job\"?\n\x16JobGetCommentsResponse\x12%\n\x08\x63omments\x18\x01 \x01(\x0b\x32\x13.comment.CommentSeq\"-\n\x14JobGetCurrentRequest\x12\x15\n\x03job\x18\x01 \x01(\x0b\x32\x08.job.Job\".\n\x15JobGetCurrentResponse\x12\x15\n\x03job\x18\x01 \x01(\x0b\x32\x08.job.Job\"-\n\x14JobGetDependsRequest\x12\x15\n\x03job\x18\x01 \x01(\x0b\x32\x08.job.Job\";\n\x15JobGetDependsResponse\x12\"\n\x07\x64\x65pends\x18\x01 \x01(\x0b\x32\x11.depend.DependSeq\"S\n\x13JobGetFramesRequest\x12\x15\n\x03job\x18\x01 \x01(\x0b\x32\x08.job.Job\x12%\n\x03req\x18\x02 \x01(\x0b\x32\x18.job.FrameSearchCriteria\"5\n\x14JobGetFramesResponse\x12\x1d\n\x06\x66rames\x18\x01 \x01(\x0b\x32\r.job.FrameSeq\"\x1e\n\x10JobGetJobRequest\x12\n\n\x02id\x18\x01 \x01(\t\"*\n\x11JobGetJobResponse\x12\x15\n\x03job\x18\x01 \x01(\x0b\x32\x08.job.Job\"6\n\x11JobGetJobsRequest\x12!\n\x01r\x18\x01 \x01(\x0b\x32\x16.job.JobSearchCriteria\"/\n\x12JobGetJobsResponse\x12\x19\n\x04jobs\x18\x01 \x01(\x0b\x32\x0b.job.JobSeq\":\n\x15JobGetJobNamesRequest\x12!\n\x01r\x18\x01 \x01(\x0b\x32\x16.job.JobSearchCriteria\"\'\n\x16JobGetJobNamesResponse\x12\r\n\x05names\x18\x01 \x03(\t\",\n\x13JobGetLayersRequest\x12\x15\n\x03job\x18\x01 \x01(\x0b\x32\x08.job.Job\"5\n\x14JobGetLayersResponse\x12\x1d\n\x06layers\x18\x01 \x01(\x0b\x32\r.job.LayerSeq\"l\n\x1aJobGetUpdatedFramesRequest\x12\x15\n\x03job\x18\x01 \x01(\x0b\x32\x08.job.Job\x12\x12\n\nlast_check\x18\x02 \x01(\x05\x12#\n\x0clayer_filter\x18\x03 \x01(\x0b\x32\r.job.LayerSeq\"~\n\x1bJobGetUpdatedFramesResponse\x12\x1c\n\x05state\x18\x01 \x01(\x0e\x32\r.job.JobState\x12\x13\n\x0bserver_time\x18\x02 \x01(\x05\x12,\n\x0eupdated_frames\x18\x03 \x01(\x0b\x32\x14.job.UpdatedFrameSeq\"7\n\x1eJobGetWhatDependsOnThisRequest\x12\x15\n\x03job\x18\x01 \x01(\x0b\x32\x08.job.Job\"E\n\x1fJobGetWhatDependsOnThisResponse\x12\"\n\x07\x64\x65pends\x18\x01 \x01(\x0b\x32\x11.depend.DependSeq\"7\n\x1eJobGetWhatThisDependsOnRequest\x12\x15\n\x03job\x18\x01 \x01(\x0b\x32\x08.job.Job\"E\n\x1fJobGetWhatThisDependsOnResponse\x12\"\n\x07\x64\x65pends\x18\x01 \x01(\x0b\x32\x11.depend.DependSeq\"&\n\x16JobIsJobPendingRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"(\n\x17JobIsJobPendingResponse\x12\r\n\x05value\x18\x01 \x01(\x08\"i\n\x0eJobKillRequest\x12\x15\n\x03job\x18\x01 \x01(\x0b\x32\x08.job.Job\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x0b\n\x03pid\x18\x03 \x01(\t\x12\x11\n\thost_kill\x18\x04 \x01(\t\x12\x0e\n\x06reason\x18\x05 \x01(\t\"\x11\n\x0fJobKillResponse\"\x96\x01\n\x14JobKillFramesRequest\x12\x15\n\x03job\x18\x01 \x01(\x0b\x32\x08.job.Job\x12%\n\x03req\x18\x02 \x01(\x0b\x32\x18.job.FrameSearchCriteria\x12\x10\n\x08username\x18\x03 \x01(\t\x12\x0b\n\x03pid\x18\x04 \x01(\t\x12\x11\n\thost_kill\x18\x05 \x01(\t\x12\x0e\n\x06reason\x18\x06 \x01(\t\"\x17\n\x15JobKillFramesResponse\"$\n\x14JobLaunchSpecRequest\x12\x0c\n\x04spec\x18\x01 \x01(\t\"&\n\x15JobLaunchSpecResponse\x12\r\n\x05names\x18\x01 \x03(\t\"+\n\x1bJobLaunchSpecAndWaitRequest\x12\x0c\n\x04spec\x18\x01 \x01(\t\"9\n\x1cJobLaunchSpecAndWaitResponse\x12\x19\n\x04jobs\x18\x01 \x01(\x0b\x32\x0b.job.JobSeq\"W\n\x17JobMarkAsWaitingRequest\x12\x15\n\x03job\x18\x01 \x01(\x0b\x32\x08.job.Job\x12%\n\x03req\x18\x02 \x01(\x0b\x32\x18.job.FrameSearchCriteria\"\x1a\n\x18JobMarkAsWaitingResponse\"X\n\x18JobMarkDoneFramesRequest\x12\x15\n\x03job\x18\x01 \x01(\x0b\x32\x08.job.Job\x12%\n\x03req\x18\x02 \x01(\x0b\x32\x18.job.FrameSearchCriteria\"\x1b\n\x19JobMarkDoneFramesResponse\"(\n\x0fJobPauseRequest\x12\x15\n\x03job\x18\x01 \x01(\x0b\x32\x08.job.Job\"\x12\n\x10JobPauseResponse\"Z\n\x17JobReorderFramesRequest\x12\x15\n\x03job\x18\x01 \x01(\x0b\x32\x08.job.Job\x12\r\n\x05range\x18\x02 \x01(\t\x12\x19\n\x05order\x18\x03 \x01(\x0e\x32\n.job.Order\"\x1a\n\x18JobReorderFramesResponse\")\n\x10JobResumeRequest\x12\x15\n\x03job\x18\x01 \x01(\x0b\x32\x08.job.Job\"\x13\n\x11JobResumeResponse\"U\n\x15JobRetryFramesRequest\x12\x15\n\x03job\x18\x01 \x01(\x0b\x32\x08.job.Job\x12%\n\x03req\x18\x02 \x01(\x0b\x32\x18.job.FrameSearchCriteria\"\x18\n\x16JobRetryFramesResponse\"-\n\x14JobRunFiltersRequest\x12\x15\n\x03job\x18\x01 \x01(\x0b\x32\x08.job.Job\"\x17\n\x15JobRunFiltersResponse\"<\n\x14JobSetAutoEatRequest\x12\x15\n\x03job\x18\x01 \x01(\x0b\x32\x08.job.Job\x12\r\n\x05value\x18\x02 \x01(\x08\"\x17\n\x15JobSetAutoEatResponse\"=\n\x12JobSetGroupRequest\x12\x15\n\x03job\x18\x01 \x01(\x0b\x32\x08.job.Job\x12\x10\n\x08group_id\x18\x02 \x01(\t\"\x15\n\x13JobSetGroupResponse\";\n\x15JobSetMaxCoresRequest\x12\x15\n\x03job\x18\x01 \x01(\x0b\x32\x08.job.Job\x12\x0b\n\x03val\x18\x02 \x01(\x02\"\x18\n\x16JobSetMaxCoresResponse\":\n\x14JobSetMaxGpusRequest\x12\x15\n\x03job\x18\x01 \x01(\x0b\x32\x08.job.Job\x12\x0b\n\x03val\x18\x02 \x01(\x05\"\x17\n\x15JobSetMaxGpusResponse\"E\n\x17JobSetMaxRetriesRequest\x12\x15\n\x03job\x18\x01 \x01(\x0b\x32\x08.job.Job\x12\x13\n\x0bmax_retries\x18\x02 \x01(\x05\"\x1a\n\x18JobSetMaxRetriesResponse\";\n\x15JobSetMinCoresRequest\x12\x15\n\x03job\x18\x01 \x01(\x0b\x32\x08.job.Job\x12\x0b\n\x03val\x18\x02 \x01(\x02\"\x18\n\x16JobSetMinCoresResponse\":\n\x14JobSetMinGpusRequest\x12\x15\n\x03job\x18\x01 \x01(\x0b\x32\x08.job.Job\x12\x0b\n\x03val\x18\x02 \x01(\x05\"\x17\n\x15JobSetMinGpusResponse\";\n\x15JobSetPriorityRequest\x12\x15\n\x03job\x18\x01 \x01(\x0b\x32\x08.job.Job\x12\x0b\n\x03val\x18\x02 \x01(\x05\"\x18\n\x16JobSetPriorityResponse\"6\n\x1dJobShutdownIfCompletedRequest\x12\x15\n\x03job\x18\x01 \x01(\x0b\x32\x08.job.Job\" \n\x1eJobShutdownIfCompletedResponse\"P\n\x17JobStaggerFramesRequest\x12\x15\n\x03job\x18\x01 \x01(\x0b\x32\x08.job.Job\x12\r\n\x05range\x18\x02 \x01(\t\x12\x0f\n\x07stagger\x18\x03 \x01(\x05\"\x1a\n\x18JobStaggerFramesResponse\"C\n\x14LayerAddLimitRequest\x12\x19\n\x05layer\x18\x01 \x01(\x0b\x32\n.job.Layer\x12\x10\n\x08limit_id\x18\x02 \x01(\t\"\x17\n\x15LayerAddLimitResponse\"\xbd\x01\n\x1eLayerAddRenderPartitionRequest\x12\x19\n\x05layer\x18\x01 \x01(\x0b\x32\n.job.Layer\x12\x0c\n\x04host\x18\x02 \x01(\t\x12\x0f\n\x07threads\x18\x03 \x01(\x05\x12\x11\n\tmax_cores\x18\x04 \x01(\x05\x12\x12\n\nmax_memory\x18\x05 \x01(\x03\x12\x16\n\x0emax_gpu_memory\x18\x06 \x01(\x03\x12\x10\n\x08username\x18\x07 \x01(\t\x12\x10\n\x08max_gpus\x18\x08 \x01(\x05\"]\n\x1fLayerAddRenderPartitionResponse\x12:\n\x10render_partition\x18\x01 \x01(\x0b\x32 .renderPartition.RenderPartition\"W\n\x1fLayerCreateDependOnFrameRequest\x12\x19\n\x05layer\x18\x01 \x01(\x0b\x32\n.job.Layer\x12\x19\n\x05\x66rame\x18\x02 \x01(\x0b\x32\n.job.Frame\"B\n LayerCreateDependOnFrameResponse\x12\x1e\n\x06\x64\x65pend\x18\x01 \x01(\x0b\x32\x0e.depend.Depend\"Q\n\x1dLayerCreateDependOnJobRequest\x12\x19\n\x05layer\x18\x01 \x01(\x0b\x32\n.job.Layer\x12\x15\n\x03job\x18\x02 \x01(\x0b\x32\x08.job.Job\"@\n\x1eLayerCreateDependOnJobResponse\x12\x1e\n\x06\x64\x65pend\x18\x01 \x01(\x0b\x32\x0e.depend.Depend\"a\n\x1fLayerCreateDependOnLayerRequest\x12\x19\n\x05layer\x18\x01 \x01(\x0b\x32\n.job.Layer\x12#\n\x0f\x64\x65pend_on_layer\x18\x02 \x01(\x0b\x32\n.job.Layer\"B\n LayerCreateDependOnLayerResponse\x12\x1e\n\x06\x64\x65pend\x18\x01 \x01(\x0b\x32\x0e.depend.Depend\"v\n$LayerCreateFrameByFrameDependRequest\x12\x19\n\x05layer\x18\x01 \x01(\x0b\x32\n.job.Layer\x12 \n\x0c\x64\x65pend_layer\x18\x02 \x01(\x0b\x32\n.job.Layer\x12\x11\n\tany_frame\x18\x03 \x01(\x08\"G\n%LayerCreateFrameByFrameDependResponse\x12\x1e\n\x06\x64\x65pend\x18\x01 \x01(\x0b\x32\x0e.depend.Depend\"Z\n\x17LayerDropDependsRequest\x12\x19\n\x05layer\x18\x01 \x01(\x0b\x32\n.job.Layer\x12$\n\x06target\x18\x02 \x01(\x0e\x32\x14.depend.DependTarget\"\x1a\n\x18LayerDropDependsResponse\"D\n\x15LayerDropLimitRequest\x12\x19\n\x05layer\x18\x01 \x01(\x0b\x32\n.job.Layer\x12\x10\n\x08limit_id\x18\x02 \x01(\t\"\x18\n\x16LayerDropLimitResponse\"2\n\x15LayerEatFramesRequest\x12\x19\n\x05layer\x18\x01 \x01(\x0b\x32\n.job.Layer\"\x18\n\x16LayerEatFramesResponse\"M\n!LayerEnableMemoryOptimizerRequest\x12\x19\n\x05layer\x18\x01 \x01(\x0b\x32\n.job.Layer\x12\r\n\x05value\x18\x02 \x01(\x08\"$\n\"LayerEnableMemoryOptimizerResponse\"3\n\x15LayerFindLayerRequest\x12\x0b\n\x03job\x18\x01 \x01(\t\x12\r\n\x05layer\x18\x02 \x01(\t\"3\n\x16LayerFindLayerResponse\x12\x19\n\x05layer\x18\x01 \x01(\x0b\x32\n.job.Layer\"W\n\x15LayerGetFramesRequest\x12\x19\n\x05layer\x18\x01 \x01(\x0b\x32\n.job.Layer\x12#\n\x01s\x18\x02 \x01(\x0b\x32\x18.job.FrameSearchCriteria\"7\n\x16LayerGetFramesResponse\x12\x1d\n\x06\x66rames\x18\x01 \x01(\x0b\x32\r.job.FrameSeq\"\"\n\x14LayerGetLayerRequest\x12\n\n\x02id\x18\x01 \x01(\t\"2\n\x15LayerGetLayerResponse\x12\x19\n\x05layer\x18\x01 \x01(\x0b\x32\n.job.Layer\"2\n\x15LayerGetLimitsRequest\x12\x19\n\x05layer\x18\x01 \x01(\x0b\x32\n.job.Layer\"6\n\x16LayerGetLimitsResponse\x12\x1c\n\x06limits\x18\x01 \x03(\x0b\x32\x0c.limit.Limit\"7\n\x1aLayerGetOutputPathsRequest\x12\x19\n\x05layer\x18\x01 \x01(\x0b\x32\n.job.Layer\"3\n\x1bLayerGetOutputPathsResponse\x12\x14\n\x0coutput_paths\x18\x01 \x03(\t\"=\n LayerGetWhatDependsOnThisRequest\x12\x19\n\x05layer\x18\x01 \x01(\x0b\x32\n.job.Layer\"G\n!LayerGetWhatDependsOnThisResponse\x12\"\n\x07\x64\x65pends\x18\x01 \x01(\x0b\x32\x11.depend.DependSeq\"=\n LayerGetWhatThisDependsOnRequest\x12\x19\n\x05layer\x18\x01 \x01(\x0b\x32\n.job.Layer\"G\n!LayerGetWhatThisDependsOnResponse\x12\"\n\x07\x64\x65pends\x18\x01 \x01(\x0b\x32\x11.depend.DependSeq\"u\n\x16LayerKillFramesRequest\x12\x19\n\x05layer\x18\x01 \x01(\x0b\x32\n.job.Layer\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x0b\n\x03pid\x18\x03 \x01(\t\x12\x11\n\thost_kill\x18\x04 \x01(\t\x12\x0e\n\x06reason\x18\x05 \x01(\t\"\x19\n\x17LayerKillFramesResponse\"7\n\x1aLayerMarkdoneFramesRequest\x12\x19\n\x05layer\x18\x01 \x01(\x0b\x32\n.job.Layer\"\x1d\n\x1bLayerMarkdoneFramesResponse\"4\n\x17LayerRetryFramesRequest\x12\x19\n\x05layer\x18\x01 \x01(\x0b\x32\n.job.Layer\"\x1a\n\x18LayerRetryFramesResponse\"I\n\x1eLayerRegisterOutputPathRequest\x12\x19\n\x05layer\x18\x01 \x01(\x0b\x32\n.job.Layer\x12\x0c\n\x04spec\x18\x02 \x01(\t\"!\n\x1fLayerRegisterOutputPathResponse\"`\n\x19LayerReorderFramesRequest\x12\x19\n\x05layer\x18\x01 \x01(\x0b\x32\n.job.Layer\x12\r\n\x05range\x18\x02 \x01(\t\x12\x19\n\x05order\x18\x03 \x01(\x0e\x32\n.job.Order\"\x1c\n\x1aLayerReorderFramesResponse\"C\n\x17LayerSetMaxCoresRequest\x12\x19\n\x05layer\x18\x01 \x01(\x0b\x32\n.job.Layer\x12\r\n\x05\x63ores\x18\x02 \x01(\x02\"\x1a\n\x18LayerSetMaxCoresResponse\"C\n\x17LayerSetMinCoresRequest\x12\x19\n\x05layer\x18\x01 \x01(\x0b\x32\n.job.Layer\x12\r\n\x05\x63ores\x18\x02 \x01(\x02\"\x1a\n\x18LayerSetMinCoresResponse\"G\n\x15LayerSetMinGpuRequest\x12\x1d\n\x05layer\x18\x01 \x01(\x0b\x32\n.job.LayerB\x02\x18\x01\x12\x0f\n\x03gpu\x18\x02 \x01(\x03\x42\x02\x18\x01\"\x18\n\x16LayerSetMinGpuResponse\"E\n\x16LayerSetMaxGpusRequest\x12\x19\n\x05layer\x18\x01 \x01(\x0b\x32\n.job.Layer\x12\x10\n\x08max_gpus\x18\x02 \x01(\x05\"\x19\n\x17LayerSetMaxGpusResponse\"E\n\x16LayerSetMinGpusRequest\x12\x19\n\x05layer\x18\x01 \x01(\x0b\x32\n.job.Layer\x12\x10\n\x08min_gpus\x18\x02 \x01(\x05\"\x19\n\x17LayerSetMinGpusResponse\"L\n\x1bLayerSetMinGpuMemoryRequest\x12\x19\n\x05layer\x18\x01 \x01(\x0b\x32\n.job.Layer\x12\x12\n\ngpu_memory\x18\x02 \x01(\x03\"\x1e\n\x1cLayerSetMinGpuMemoryResponse\"E\n\x18LayerSetMinMemoryRequest\x12\x19\n\x05layer\x18\x01 \x01(\x0b\x32\n.job.Layer\x12\x0e\n\x06memory\x18\x02 \x01(\x03\"\x1b\n\x19LayerSetMinMemoryResponse\">\n\x13LayerSetTagsRequest\x12\x19\n\x05layer\x18\x01 \x01(\x0b\x32\n.job.Layer\x12\x0c\n\x04tags\x18\x02 \x03(\t\"\x16\n\x14LayerSetTagsResponse\"J\n\x19LayerSetThreadableRequest\x12\x19\n\x05layer\x18\x01 \x01(\x0b\x32\n.job.Layer\x12\x12\n\nthreadable\x18\x02 \x01(\x08\"\x1c\n\x1aLayerSetThreadableResponse\"D\n\x16LayerSetTimeoutRequest\x12\x19\n\x05layer\x18\x01 \x01(\x0b\x32\n.job.Layer\x12\x0f\n\x07timeout\x18\x02 \x01(\x05\"\x19\n\x17LayerSetTimeoutResponse\"K\n\x19LayerSetTimeoutLLURequest\x12\x19\n\x05layer\x18\x01 \x01(\x0b\x32\n.job.Layer\x12\x13\n\x0btimeout_llu\x18\x02 \x01(\x05\"\x1c\n\x1aLayerSetTimeoutLLUResponse\"V\n\x19LayerStaggerFramesRequest\x12\x19\n\x05layer\x18\x01 \x01(\x0b\x32\n.job.Layer\x12\r\n\x05range\x18\x02 \x01(\t\x12\x0f\n\x07stagger\x18\x03 \x01(\x05\"\x1c\n\x1aLayerStaggerFramesResponse\"o\n FrameStateDisplayOverrideRequest\x12\x19\n\x05\x66rame\x18\x01 \x01(\x0b\x32\n.job.Frame\x12\x30\n\x08override\x18\x02 \x01(\x0b\x32\x1e.job.FrameStateDisplayOverride\"#\n!FrameStateDisplayOverrideResponse\"A\n$GetFrameStateDisplayOverridesRequest\x12\x19\n\x05\x66rame\x18\x01 \x01(\x0b\x32\n.job.Frame\"]\n%GetFrameStateDisplayOverridesResponse\x12\x34\n\toverrides\x18\x01 \x01(\x0b\x32!.job.FrameStateDisplayOverrideSeq*G\n\x0f\x43heckpointState\x12\x0c\n\x08\x44ISABLED\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0b\n\x07\x43OPYING\x10\x02\x12\x0c\n\x08\x43OMPLETE\x10\x03*C\n\x0f\x46rameExitStatus\x12\x0b\n\x07SUCCESS\x10\x00\x12\x12\n\rFAILED_LAUNCH\x10\x80\x02\x12\x0f\n\nSKIP_RETRY\x10\x9e\x02*q\n\nFrameState\x12\x0b\n\x07WAITING\x10\x00\x12\t\n\x05SETUP\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\r\n\tSUCCEEDED\x10\x03\x12\n\n\x06\x44\x45PEND\x10\x04\x12\x08\n\x04\x44\x45\x41\x44\x10\x05\x12\t\n\x05\x45\x41TEN\x10\x06\x12\x0e\n\nCHECKPOINT\x10\x07*L\n\x08JobState\x12\x0b\n\x07PENDING\x10\x00\x12\x0c\n\x08\x46INISHED\x10\x01\x12\x0b\n\x07STARTUP\x10\x02\x12\x0c\n\x08SHUTDOWN\x10\x03\x12\n\n\x06POSTED\x10\x04*4\n\tLayerType\x12\x07\n\x03PRE\x10\x00\x12\x08\n\x04POST\x10\x01\x12\n\n\x06RENDER\x10\x02\x12\x08\n\x04UTIL\x10\x03*)\n\x05Order\x12\t\n\x05\x46IRST\x10\x00\x12\x08\n\x04LAST\x10\x01\x12\x0b\n\x07REVERSE\x10\x02\x32\xb2\x0c\n\x0e\x46rameInterface\x12_\n\x12\x41\x64\x64RenderPartition\x12#.job.FrameAddRenderPartitionRequest\x1a$.job.FrameAddRenderPartitionResponse\x12n\n\x17\x43reateDependencyOnFrame\x12(.job.FrameCreateDependencyOnFrameRequest\x1a).job.FrameCreateDependencyOnFrameResponse\x12h\n\x15\x43reateDependencyOnJob\x12&.job.FrameCreateDependencyOnJobRequest\x1a\'.job.FrameCreateDependencyOnJobResponse\x12n\n\x17\x43reateDependencyOnLayer\x12(.job.FrameCreateDependencyOnLayerRequest\x1a).job.FrameCreateDependencyOnLayerResponse\x12J\n\x0b\x44ropDepends\x12\x1c.job.FrameDropDependsRequest\x1a\x1d.job.FrameDropDependsResponse\x12\x32\n\x03\x45\x61t\x12\x14.job.FrameEatRequest\x1a\x15.job.FrameEatResponse\x12\x44\n\tFindFrame\x12\x1a.job.FrameFindFrameRequest\x1a\x1b.job.FrameFindFrameResponse\x12\x41\n\x08GetFrame\x12\x19.job.FrameGetFrameRequest\x1a\x1a.job.FrameGetFrameResponse\x12\x44\n\tGetFrames\x12\x1a.job.FrameGetFramesRequest\x1a\x1b.job.FrameGetFramesResponse\x12\x65\n\x14GetWhatDependsOnThis\x12%.job.FrameGetWhatDependsOnThisRequest\x1a&.job.FrameGetWhatDependsOnThisResponse\x12\x65\n\x14GetWhatThisDependsOn\x12%.job.FrameGetWhatThisDependsOnRequest\x1a&.job.FrameGetWhatThisDependsOnResponse\x12\x35\n\x04Kill\x12\x15.job.FrameKillRequest\x1a\x16.job.FrameKillResponse\x12M\n\x0cMarkAsDepend\x12\x1d.job.FrameMarkAsDependRequest\x1a\x1e.job.FrameMarkAsDependResponse\x12P\n\rMarkAsWaiting\x12\x1e.job.FrameMarkAsWaitingRequest\x1a\x1f.job.FrameMarkAsWaitingResponse\x12\x38\n\x05Retry\x12\x16.job.FrameRetryRequest\x1a\x17.job.FrameRetryResponse\x12_\n\x12SetCheckpointState\x12#.job.FrameSetCheckpointStateRequest\x1a$.job.FrameSetCheckpointStateResponse\x12m\n\x1cSetFrameStateDisplayOverride\x12%.job.FrameStateDisplayOverrideRequest\x1a&.job.FrameStateDisplayOverrideResponse\x12v\n\x1dGetFrameStateDisplayOverrides\x12).job.GetFrameStateDisplayOverridesRequest\x1a*.job.GetFrameStateDisplayOverridesResponse2\xac\x0c\n\x0eGroupInterface\x12S\n\x0e\x43reateSubGroup\x12\x1f.job.GroupCreateSubGroupRequest\x1a .job.GroupCreateSubGroupResponse\x12;\n\x06\x44\x65lete\x12\x17.job.GroupDeleteRequest\x1a\x18.job.GroupDeleteResponse\x12\x44\n\tFindGroup\x12\x1a.job.GroupFindGroupRequest\x1a\x1b.job.GroupFindGroupResponse\x12\x41\n\x08GetGroup\x12\x19.job.GroupGetGroupRequest\x1a\x1a.job.GroupGetGroupResponse\x12\x44\n\tGetGroups\x12\x1a.job.GroupGetGroupsRequest\x1a\x1b.job.GroupGetGroupsResponse\x12>\n\x07GetJobs\x12\x18.job.GroupGetJobsRequest\x1a\x19.job.GroupGetJobsResponse\x12S\n\x0eReparentGroups\x12\x1f.job.GroupReparentGroupsRequest\x1a .job.GroupReparentGroupsResponse\x12M\n\x0cReparentJobs\x12\x1d.job.GroupReparentJobsRequest\x1a\x1e.job.GroupReparentJobsResponse\x12`\n\x15SetDefaultJobMaxCores\x12\".job.GroupSetDefJobMaxCoresRequest\x1a#.job.GroupSetDefJobMaxCoresResponse\x12`\n\x15SetDefaultJobMinCores\x12\".job.GroupSetDefJobMinCoresRequest\x1a#.job.GroupSetDefJobMinCoresResponse\x12]\n\x14SetDefaultJobMaxGpus\x12!.job.GroupSetDefJobMaxGpusRequest\x1a\".job.GroupSetDefJobMaxGpusResponse\x12]\n\x14SetDefaultJobMinGpus\x12!.job.GroupSetDefJobMinGpusRequest\x1a\".job.GroupSetDefJobMinGpusResponse\x12`\n\x15SetDefaultJobPriority\x12\".job.GroupSetDefJobPriorityRequest\x1a#.job.GroupSetDefJobPriorityResponse\x12\x44\n\rSetDepartment\x12\x18.job.GroupSetDeptRequest\x1a\x19.job.GroupSetDeptResponse\x12\x41\n\x08SetGroup\x12\x19.job.GroupSetGroupRequest\x1a\x1a.job.GroupSetGroupResponse\x12J\n\x0bSetMaxCores\x12\x1c.job.GroupSetMaxCoresRequest\x1a\x1d.job.GroupSetMaxCoresResponse\x12J\n\x0bSetMinCores\x12\x1c.job.GroupSetMinCoresRequest\x1a\x1d.job.GroupSetMinCoresResponse\x12G\n\nSetMaxGpus\x12\x1b.job.GroupSetMaxGpusRequest\x1a\x1c.job.GroupSetMaxGpusResponse\x12G\n\nSetMinGpus\x12\x1b.job.GroupSetMinGpusRequest\x1a\x1c.job.GroupSetMinGpusResponse\x12>\n\x07SetName\x12\x18.job.GroupSetNameRequest\x1a\x19.job.GroupSetNameResponse2\xd5\x18\n\x0cJobInterface\x12\x43\n\nAddComment\x12\x19.job.JobAddCommentRequest\x1a\x1a.job.JobAddCommentResponse\x12Q\n\x12\x41\x64\x64RenderPartition\x12\x1c.job.JobAddRenderPartRequest\x1a\x1d.job.JobAddRenderPartResponse\x12L\n\rAddSubscriber\x12\x1c.job.JobAddSubscriberRequest\x1a\x1d.job.JobAddSubscriberResponse\x12j\n\x17\x43reateDependencyOnFrame\x12&.job.JobCreateDependencyOnFrameRequest\x1a\'.job.JobCreateDependencyOnFrameResponse\x12\x64\n\x15\x43reateDependencyOnJob\x12$.job.JobCreateDependencyOnJobRequest\x1a%.job.JobCreateDependencyOnJobResponse\x12j\n\x17\x43reateDependencyOnLayer\x12&.job.JobCreateDependencyOnLayerRequest\x1a\'.job.JobCreateDependencyOnLayerResponse\x12\x46\n\x0b\x44ropDepends\x12\x1a.job.JobDropDependsRequest\x1a\x1b.job.JobDropDependsResponse\x12@\n\tEatFrames\x12\x18.job.JobEatFramesRequest\x1a\x19.job.JobEatFramesResponse\x12:\n\x07\x46indJob\x12\x16.job.JobFindJobRequest\x1a\x17.job.JobFindJobResponse\x12\x46\n\x0bGetComments\x12\x1a.job.JobGetCommentsRequest\x1a\x1b.job.JobGetCommentsResponse\x12\x43\n\nGetCurrent\x12\x19.job.JobGetCurrentRequest\x1a\x1a.job.JobGetCurrentResponse\x12\x43\n\nGetDepends\x12\x19.job.JobGetDependsRequest\x1a\x1a.job.JobGetDependsResponse\x12@\n\tGetFrames\x12\x18.job.JobGetFramesRequest\x1a\x19.job.JobGetFramesResponse\x12\x37\n\x06GetJob\x12\x15.job.JobGetJobRequest\x1a\x16.job.JobGetJobResponse\x12:\n\x07GetJobs\x12\x16.job.JobGetJobsRequest\x1a\x17.job.JobGetJobsResponse\x12\x46\n\x0bGetJobNames\x12\x1a.job.JobGetJobNamesRequest\x1a\x1b.job.JobGetJobNamesResponse\x12@\n\tGetLayers\x12\x18.job.JobGetLayersRequest\x1a\x19.job.JobGetLayersResponse\x12U\n\x10GetUpdatedFrames\x12\x1f.job.JobGetUpdatedFramesRequest\x1a .job.JobGetUpdatedFramesResponse\x12\x61\n\x14GetWhatDependsOnThis\x12#.job.JobGetWhatDependsOnThisRequest\x1a$.job.JobGetWhatDependsOnThisResponse\x12\x61\n\x14GetWhatThisDependsOn\x12#.job.JobGetWhatThisDependsOnRequest\x1a$.job.JobGetWhatThisDependsOnResponse\x12I\n\x0cIsJobPending\x12\x1b.job.JobIsJobPendingRequest\x1a\x1c.job.JobIsJobPendingResponse\x12\x31\n\x04Kill\x12\x13.job.JobKillRequest\x1a\x14.job.JobKillResponse\x12\x43\n\nKillFrames\x12\x19.job.JobKillFramesRequest\x1a\x1a.job.JobKillFramesResponse\x12X\n\x11LaunchSpecAndWait\x12 .job.JobLaunchSpecAndWaitRequest\x1a!.job.JobLaunchSpecAndWaitResponse\x12\x43\n\nLaunchSpec\x12\x19.job.JobLaunchSpecRequest\x1a\x1a.job.JobLaunchSpecResponse\x12L\n\rMarkAsWaiting\x12\x1c.job.JobMarkAsWaitingRequest\x1a\x1d.job.JobMarkAsWaitingResponse\x12O\n\x0eMarkDoneFrames\x12\x1d.job.JobMarkDoneFramesRequest\x1a\x1e.job.JobMarkDoneFramesResponse\x12\x34\n\x05Pause\x12\x14.job.JobPauseRequest\x1a\x15.job.JobPauseResponse\x12L\n\rReorderFrames\x12\x1c.job.JobReorderFramesRequest\x1a\x1d.job.JobReorderFramesResponse\x12\x37\n\x06Resume\x12\x15.job.JobResumeRequest\x1a\x16.job.JobResumeResponse\x12\x46\n\x0bRetryFrames\x12\x1a.job.JobRetryFramesRequest\x1a\x1b.job.JobRetryFramesResponse\x12\x43\n\nRunFilters\x12\x19.job.JobRunFiltersRequest\x1a\x1a.job.JobRunFiltersResponse\x12\x43\n\nSetAutoEat\x12\x19.job.JobSetAutoEatRequest\x1a\x1a.job.JobSetAutoEatResponse\x12=\n\x08SetGroup\x12\x17.job.JobSetGroupRequest\x1a\x18.job.JobSetGroupResponse\x12\x46\n\x0bSetMaxCores\x12\x1a.job.JobSetMaxCoresRequest\x1a\x1b.job.JobSetMaxCoresResponse\x12L\n\rSetMaxRetries\x12\x1c.job.JobSetMaxRetriesRequest\x1a\x1d.job.JobSetMaxRetriesResponse\x12\x46\n\x0bSetMinCores\x12\x1a.job.JobSetMinCoresRequest\x1a\x1b.job.JobSetMinCoresResponse\x12\x43\n\nSetMaxGpus\x12\x19.job.JobSetMaxGpusRequest\x1a\x1a.job.JobSetMaxGpusResponse\x12\x43\n\nSetMinGpus\x12\x19.job.JobSetMinGpusRequest\x1a\x1a.job.JobSetMinGpusResponse\x12\x46\n\x0bSetPriority\x12\x1a.job.JobSetPriorityRequest\x1a\x1b.job.JobSetPriorityResponse\x12^\n\x13ShutdownIfCompleted\x12\".job.JobShutdownIfCompletedRequest\x1a#.job.JobShutdownIfCompletedResponse\x12L\n\rStaggerFrames\x12\x1c.job.JobStaggerFramesRequest\x1a\x1d.job.JobStaggerFramesResponse2\x8a\x16\n\x0eLayerInterface\x12\x41\n\x08\x41\x64\x64Limit\x12\x19.job.LayerAddLimitRequest\x1a\x1a.job.LayerAddLimitResponse\x12_\n\x12\x41\x64\x64RenderPartition\x12#.job.LayerAddRenderPartitionRequest\x1a$.job.LayerAddRenderPartitionResponse\x12\x66\n\x17\x43reateDependencyOnFrame\x12$.job.LayerCreateDependOnFrameRequest\x1a%.job.LayerCreateDependOnFrameResponse\x12`\n\x15\x43reateDependencyOnJob\x12\".job.LayerCreateDependOnJobRequest\x1a#.job.LayerCreateDependOnJobResponse\x12\x66\n\x17\x43reateDependencyOnLayer\x12$.job.LayerCreateDependOnLayerRequest\x1a%.job.LayerCreateDependOnLayerResponse\x12u\n\x1c\x43reateFrameByFrameDependency\x12).job.LayerCreateFrameByFrameDependRequest\x1a*.job.LayerCreateFrameByFrameDependResponse\x12J\n\x0b\x44ropDepends\x12\x1c.job.LayerDropDependsRequest\x1a\x1d.job.LayerDropDependsResponse\x12\x44\n\tDropLimit\x12\x1a.job.LayerDropLimitRequest\x1a\x1b.job.LayerDropLimitResponse\x12\x44\n\tEatFrames\x12\x1a.job.LayerEatFramesRequest\x1a\x1b.job.LayerEatFramesResponse\x12h\n\x15\x45nableMemoryOptimizer\x12&.job.LayerEnableMemoryOptimizerRequest\x1a\'.job.LayerEnableMemoryOptimizerResponse\x12\x44\n\tFindLayer\x12\x1a.job.LayerFindLayerRequest\x1a\x1b.job.LayerFindLayerResponse\x12\x44\n\tGetFrames\x12\x1a.job.LayerGetFramesRequest\x1a\x1b.job.LayerGetFramesResponse\x12\x41\n\x08GetLayer\x12\x19.job.LayerGetLayerRequest\x1a\x1a.job.LayerGetLayerResponse\x12\x44\n\tGetLimits\x12\x1a.job.LayerGetLimitsRequest\x1a\x1b.job.LayerGetLimitsResponse\x12S\n\x0eGetOutputPaths\x12\x1f.job.LayerGetOutputPathsRequest\x1a .job.LayerGetOutputPathsResponse\x12\x65\n\x14GetWhatThisDependsOn\x12%.job.LayerGetWhatThisDependsOnRequest\x1a&.job.LayerGetWhatThisDependsOnResponse\x12\x65\n\x14GetWhatDependsOnThis\x12%.job.LayerGetWhatDependsOnThisRequest\x1a&.job.LayerGetWhatDependsOnThisResponse\x12G\n\nKillFrames\x12\x1b.job.LayerKillFramesRequest\x1a\x1c.job.LayerKillFramesResponse\x12S\n\x0eMarkdoneFrames\x12\x1f.job.LayerMarkdoneFramesRequest\x1a .job.LayerMarkdoneFramesResponse\x12_\n\x12RegisterOutputPath\x12#.job.LayerRegisterOutputPathRequest\x1a$.job.LayerRegisterOutputPathResponse\x12P\n\rReorderFrames\x12\x1e.job.LayerReorderFramesRequest\x1a\x1f.job.LayerReorderFramesResponse\x12J\n\x0bRetryFrames\x12\x1c.job.LayerRetryFramesRequest\x1a\x1d.job.LayerRetryFramesResponse\x12J\n\x0bSetMaxCores\x12\x1c.job.LayerSetMaxCoresRequest\x1a\x1d.job.LayerSetMaxCoresResponse\x12J\n\x0bSetMinCores\x12\x1c.job.LayerSetMinCoresRequest\x1a\x1d.job.LayerSetMinCoresResponse\x12G\n\nSetMaxGpus\x12\x1b.job.LayerSetMaxGpusRequest\x1a\x1c.job.LayerSetMaxGpusResponse\x12G\n\nSetMinGpus\x12\x1b.job.LayerSetMinGpusRequest\x1a\x1c.job.LayerSetMinGpusResponse\x12V\n\x0fSetMinGpuMemory\x12 .job.LayerSetMinGpuMemoryRequest\x1a!.job.LayerSetMinGpuMemoryResponse\x12\x44\n\tSetMinGpu\x12\x1a.job.LayerSetMinGpuRequest\x1a\x1b.job.LayerSetMinGpuResponse\x12M\n\x0cSetMinMemory\x12\x1d.job.LayerSetMinMemoryRequest\x1a\x1e.job.LayerSetMinMemoryResponse\x12>\n\x07SetTags\x12\x18.job.LayerSetTagsRequest\x1a\x19.job.LayerSetTagsResponse\x12P\n\rSetThreadable\x12\x1e.job.LayerSetThreadableRequest\x1a\x1f.job.LayerSetThreadableResponse\x12G\n\nSetTimeout\x12\x1b.job.LayerSetTimeoutRequest\x1a\x1c.job.LayerSetTimeoutResponse\x12P\n\rSetTimeoutLLU\x12\x1e.job.LayerSetTimeoutLLURequest\x1a\x1f.job.LayerSetTimeoutLLUResponse\x12P\n\rStaggerFrames\x12\x1e.job.LayerStaggerFramesRequest\x1a\x1f.job.LayerStaggerFramesResponseB9\n\x1d\x63om.imageworks.spcue.grpc.jobP\x01Z\x16opencue_gateway/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'job_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035com.imageworks.spcue.grpc.jobP\001Z\026opencue_gateway/gen/go'
  _globals['_LAYERSETMINGPUREQUEST'].fields_by_name['layer']._options = None
  _globals['_LAYERSETMINGPUREQUEST'].fields_by_name['layer']._serialized_options = b'\030\001'
  _globals['_LAYERSETMINGPUREQUEST'].fields_by_name['gpu']._options = None
  _globals['_LAYERSETMINGPUREQUEST'].fields_by_name['gpu']._serialized_options = b'\030\001'
  _globals['_CHECKPOINTSTATE']._serialized_start=18946
  _globals['_CHECKPOINTSTATE']._serialized_end=19017
  _globals['_FRAMEEXITSTATUS']._serialized_start=19019
  _globals['_FRAMEEXITSTATUS']._serialized_end=19086
  _globals['_FRAMESTATE']._serialized_start=19088
  _globals['_FRAMESTATE']._serialized_end=19201
  _globals['_JOBSTATE']._serialized_start=19203
  _globals['_JOBSTATE']._serialized_end=19279
  _globals['_LAYERTYPE']._serialized_start=19281
  _globals['_LAYERTYPE']._serialized_end=19333
  _globals['_ORDER']._serialized_start=19335
  _globals['_ORDER']._serialized_end=19376
  _globals['_FRAMESTATEDISPLAYOVERRIDE']._serialized_start=84
  _globals['_FRAMESTATEDISPLAYOVERRIDE']._serialized_end=257
  _globals['_FRAMESTATEDISPLAYOVERRIDE_RGB']._serialized_start=210
  _globals['_FRAMESTATEDISPLAYOVERRIDE_RGB']._serialized_end=257
  _globals['_FRAMESTATEDISPLAYOVERRIDESEQ']._serialized_start=259
  _globals['_FRAMESTATEDISPLAYOVERRIDESEQ']._serialized_end=340
  _globals['_FRAME']._serialized_start=343
  _globals['_FRAME']._serialized_end=924
  _globals['_FRAMESEARCHCRITERIA']._serialized_start=927
  _globals['_FRAMESEARCHCRITERIA']._serialized_end=1209
  _globals['_FRAMESEQ']._serialized_start=1211
  _globals['_FRAMESEQ']._serialized_end=1249
  _globals['_FRAMESTATESEQ']._serialized_start=1251
  _globals['_FRAMESTATESEQ']._serialized_end=1305
  _globals['_UPDATEDFRAME']._serialized_start=1308
  _globals['_UPDATEDFRAME']._serialized_end=1645
  _globals['_UPDATEDFRAMESEQ']._serialized_start=1647
  _globals['_UPDATEDFRAMESEQ']._serialized_end=1707
  _globals['_UPDATEDFRAMECHECKRESULT']._serialized_start=1709
  _globals['_UPDATEDFRAMECHECKRESULT']._serialized_end=1831
  _globals['_GROUP']._serialized_start=1834
  _globals['_GROUP']._serialized_end=2185
  _globals['_GROUPSEQ']._serialized_start=2187
  _globals['_GROUPSEQ']._serialized_end=2225
  _globals['_GROUPSTATS']._serialized_start=2228
  _globals['_GROUPSTATS']._serialized_end=2401
  _globals['_JOB']._serialized_start=2404
  _globals['_JOB']._serialized_end=2841
  _globals['_JOBSEARCHCRITERIA']._serialized_start=2844
  _globals['_JOBSEARCHCRITERIA']._serialized_end=2992
  _globals['_JOBSEQ']._serialized_start=2994
  _globals['_JOBSEQ']._serialized_end=3026
  _globals['_JOBSTATS']._serialized_start=3029
  _globals['_JOBSTATS']._serialized_end=3639
  _globals['_LAYER']._serialized_start=3642
  _globals['_LAYER']._serialized_end=4099
  _globals['_LAYERSEQ']._serialized_start=4101
  _globals['_LAYERSEQ']._serialized_end=4139
  _globals['_LAYERSTATS']._serialized_start=4142
  _globals['_LAYERSTATS']._serialized_end=4755
  _globals['_NESTEDGROUP']._serialized_start=4758
  _globals['_NESTEDGROUP']._serialized_end=5175
  _globals['_NESTEDGROUPSEQ']._serialized_start=5177
  _globals['_NESTEDGROUPSEQ']._serialized_end=5234
  _globals['_NESTEDJOB']._serialized_start=5237
  _globals['_NESTEDJOB']._serialized_end=5692
  _globals['_FRAMEADDRENDERPARTITIONREQUEST']._serialized_start=5695
  _globals['_FRAMEADDRENDERPARTITIONREQUEST']._serialized_end=5884
  _globals['_FRAMEADDRENDERPARTITIONRESPONSE']._serialized_start=5886
  _globals['_FRAMEADDRENDERPARTITIONRESPONSE']._serialized_end=5979
  _globals['_FRAMECREATEDEPENDENCYONFRAMEREQUEST']._serialized_start=5981
  _globals['_FRAMECREATEDEPENDENCYONFRAMEREQUEST']._serialized_end=6082
  _globals['_FRAMECREATEDEPENDENCYONFRAMERESPONSE']._serialized_start=6084
  _globals['_FRAMECREATEDEPENDENCYONFRAMERESPONSE']._serialized_end=6154
  _globals['_FRAMECREATEDEPENDENCYONJOBREQUEST']._serialized_start=6156
  _globals['_FRAMECREATEDEPENDENCYONJOBREQUEST']._serialized_end=6241
  _globals['_FRAMECREATEDEPENDENCYONJOBRESPONSE']._serialized_start=6243
  _globals['_FRAMECREATEDEPENDENCYONJOBRESPONSE']._serialized_end=6311
  _globals['_FRAMECREATEDEPENDENCYONLAYERREQUEST']._serialized_start=6313
  _globals['_FRAMECREATEDEPENDENCYONLAYERREQUEST']._serialized_end=6404
  _globals['_FRAMECREATEDEPENDENCYONLAYERRESPONSE']._serialized_start=6406
  _globals['_FRAMECREATEDEPENDENCYONLAYERRESPONSE']._serialized_end=6476
  _globals['_FRAMEDROPDEPENDSREQUEST']._serialized_start=6478
  _globals['_FRAMEDROPDEPENDSREQUEST']._serialized_end=6568
  _globals['_FRAMEDROPDEPENDSRESPONSE']._serialized_start=6570
  _globals['_FRAMEDROPDEPENDSRESPONSE']._serialized_end=6596
  _globals['_FRAMEEATREQUEST']._serialized_start=6598
  _globals['_FRAMEEATREQUEST']._serialized_end=6642
  _globals['_FRAMEEATRESPONSE']._serialized_start=6644
  _globals['_FRAMEEATRESPONSE']._serialized_end=6662
  _globals['_FRAMEFINDFRAMEREQUEST']._serialized_start=6664
  _globals['_FRAMEFINDFRAMEREQUEST']._serialized_end=6730
  _globals['_FRAMEFINDFRAMERESPONSE']._serialized_start=6732
  _globals['_FRAMEFINDFRAMERESPONSE']._serialized_end=6783
  _globals['_FRAMEGETFRAMEREQUEST']._serialized_start=6785
  _globals['_FRAMEGETFRAMEREQUEST']._serialized_end=6819
  _globals['_FRAMEGETFRAMERESPONSE']._serialized_start=6821
  _globals['_FRAMEGETFRAMERESPONSE']._serialized_end=6871
  _globals['_FRAMEGETFRAMESREQUEST']._serialized_start=6873
  _globals['_FRAMEGETFRAMESREQUEST']._serialized_end=6946
  _globals['_FRAMEGETFRAMESRESPONSE']._serialized_start=6948
  _globals['_FRAMEGETFRAMESRESPONSE']._serialized_end=7003
  _globals['_FRAMEGETWHATDEPENDSONTHISREQUEST']._serialized_start=7005
  _globals['_FRAMEGETWHATDEPENDSONTHISREQUEST']._serialized_end=7066
  _globals['_FRAMEGETWHATDEPENDSONTHISRESPONSE']._serialized_start=7068
  _globals['_FRAMEGETWHATDEPENDSONTHISRESPONSE']._serialized_end=7139
  _globals['_FRAMEGETWHATTHISDEPENDSONREQUEST']._serialized_start=7141
  _globals['_FRAMEGETWHATTHISDEPENDSONREQUEST']._serialized_end=7202
  _globals['_FRAMEGETWHATTHISDEPENDSONRESPONSE']._serialized_start=7204
  _globals['_FRAMEGETWHATTHISDEPENDSONRESPONSE']._serialized_end=7275
  _globals['_FRAMEKILLREQUEST']._serialized_start=7277
  _globals['_FRAMEKILLREQUEST']._serialized_end=7388
  _globals['_FRAMEKILLRESPONSE']._serialized_start=7390
  _globals['_FRAMEKILLRESPONSE']._serialized_end=7409
  _globals['_FRAMEMARKASDEPENDREQUEST']._serialized_start=7411
  _globals['_FRAMEMARKASDEPENDREQUEST']._serialized_end=7464
  _globals['_FRAMEMARKASDEPENDRESPONSE']._serialized_start=7466
  _globals['_FRAMEMARKASDEPENDRESPONSE']._serialized_end=7493
  _globals['_FRAMEMARKASWAITINGREQUEST']._serialized_start=7495
  _globals['_FRAMEMARKASWAITINGREQUEST']._serialized_end=7549
  _globals['_FRAMEMARKASWAITINGRESPONSE']._serialized_start=7551
  _globals['_FRAMEMARKASWAITINGRESPONSE']._serialized_end=7579
  _globals['_FRAMERETRYREQUEST']._serialized_start=7581
  _globals['_FRAMERETRYREQUEST']._serialized_end=7627
  _globals['_FRAMERETRYRESPONSE']._serialized_start=7629
  _globals['_FRAMERETRYRESPONSE']._serialized_end=7649
  _globals['_FRAMESETCHECKPOINTSTATEREQUEST']._serialized_start=7651
  _globals['_FRAMESETCHECKPOINTSTATEREQUEST']._serialized_end=7747
  _globals['_FRAMESETCHECKPOINTSTATERESPONSE']._serialized_start=7749
  _globals['_FRAMESETCHECKPOINTSTATERESPONSE']._serialized_end=7782
  _globals['_GROUPCREATESUBGROUPREQUEST']._serialized_start=7784
  _globals['_GROUPCREATESUBGROUPREQUEST']._serialized_end=7853
  _globals['_GROUPCREATESUBGROUPRESPONSE']._serialized_start=7855
  _globals['_GROUPCREATESUBGROUPRESPONSE']._serialized_end=7911
  _globals['_GROUPDELETEREQUEST']._serialized_start=7913
  _globals['_GROUPDELETEREQUEST']._serialized_end=7960
  _globals['_GROUPDELETERESPONSE']._serialized_start=7962
  _globals['_GROUPDELETERESPONSE']._serialized_end=7983
  _globals['_GROUPFINDGROUPREQUEST']._serialized_start=7985
  _globals['_GROUPFINDGROUPREQUEST']._serialized_end=8036
  _globals['_GROUPFINDGROUPRESPONSE']._serialized_start=8038
  _globals['_GROUPFINDGROUPRESPONSE']._serialized_end=8089
  _globals['_GROUPGETGROUPREQUEST']._serialized_start=8091
  _globals['_GROUPGETGROUPREQUEST']._serialized_end=8125
  _globals['_GROUPGETGROUPRESPONSE']._serialized_start=8127
  _globals['_GROUPGETGROUPRESPONSE']._serialized_end=8177
  _globals['_GROUPGETGROUPSREQUEST']._serialized_start=8179
  _globals['_GROUPGETGROUPSREQUEST']._serialized_end=8229
  _globals['_GROUPGETGROUPSRESPONSE']._serialized_start=8231
  _globals['_GROUPGETGROUPSRESPONSE']._serialized_end=8286
  _globals['_GROUPGETJOBSREQUEST']._serialized_start=8288
  _globals['_GROUPGETJOBSREQUEST']._serialized_end=8336
  _globals['_GROUPGETJOBSRESPONSE']._serialized_start=8338
  _globals['_GROUPGETJOBSRESPONSE']._serialized_end=8387
  _globals['_GROUPREPARENTGROUPSREQUEST']._serialized_start=8389
  _globals['_GROUPREPARENTGROUPSREQUEST']._serialized_end=8475
  _globals['_GROUPREPARENTGROUPSRESPONSE']._serialized_start=8477
  _globals['_GROUPREPARENTGROUPSRESPONSE']._serialized_end=8506
  _globals['_GROUPREPARENTJOBSREQUEST']._serialized_start=8508
  _globals['_GROUPREPARENTJOBSREQUEST']._serialized_end=8588
  _globals['_GROUPREPARENTJOBSRESPONSE']._serialized_start=8590
  _globals['_GROUPREPARENTJOBSRESPONSE']._serialized_end=8617
  _globals['_GROUPSETDEFJOBMAXCORESREQUEST']._serialized_start=8619
  _globals['_GROUPSETDEFJOBMAXCORESREQUEST']._serialized_end=8696
  _globals['_GROUPSETDEFJOBMAXCORESRESPONSE']._serialized_start=8698
  _globals['_GROUPSETDEFJOBMAXCORESRESPONSE']._serialized_end=8730
  _globals['_GROUPSETDEFJOBMINCORESREQUEST']._serialized_start=8732
  _globals['_GROUPSETDEFJOBMINCORESREQUEST']._serialized_end=8809
  _globals['_GROUPSETDEFJOBMINCORESRESPONSE']._serialized_start=8811
  _globals['_GROUPSETDEFJOBMINCORESRESPONSE']._serialized_end=8843
  _globals['_GROUPSETDEFJOBMAXGPUSREQUEST']._serialized_start=8845
  _globals['_GROUPSETDEFJOBMAXGPUSREQUEST']._serialized_end=8920
  _globals['_GROUPSETDEFJOBMAXGPUSRESPONSE']._serialized_start=8922
  _globals['_GROUPSETDEFJOBMAXGPUSRESPONSE']._serialized_end=8953
  _globals['_GROUPSETDEFJOBMINGPUSREQUEST']._serialized_start=8955
  _globals['_GROUPSETDEFJOBMINGPUSREQUEST']._serialized_end=9030
  _globals['_GROUPSETDEFJOBMINGPUSRESPONSE']._serialized_start=9032
  _globals['_GROUPSETDEFJOBMINGPUSRESPONSE']._serialized_end=9063
  _globals['_GROUPSETDEFJOBPRIORITYREQUEST']._serialized_start=9065
  _globals['_GROUPSETDEFJOBPRIORITYREQUEST']._serialized_end=9141
  _globals['_GROUPSETDEFJOBPRIORITYRESPONSE']._serialized_start=9143
  _globals['_GROUPSETDEFJOBPRIORITYRESPONSE']._serialized_end=9175
  _globals['_GROUPSETDEPTREQUEST']._serialized_start=9177
  _globals['_GROUPSETDEPTREQUEST']._serialized_end=9239
  _globals['_GROUPSETDEPTRESPONSE']._serialized_start=9241
  _globals['_GROUPSETDEPTRESPONSE']._serialized_end=9263
  _globals['_GROUPSETGROUPREQUEST']._serialized_start=9265
  _globals['_GROUPSETGROUPREQUEST']._serialized_end=9348
  _globals['_GROUPSETGROUPRESPONSE']._serialized_start=9350
  _globals['_GROUPSETGROUPRESPONSE']._serialized_end=9373
  _globals['_GROUPSETMAXCORESREQUEST']._serialized_start=9375
  _globals['_GROUPSETMAXCORESREQUEST']._serialized_end=9446
  _globals['_GROUPSETMAXCORESRESPONSE']._serialized_start=9448
  _globals['_GROUPSETMAXCORESRESPONSE']._serialized_end=9474
  _globals['_GROUPSETMINCORESREQUEST']._serialized_start=9476
  _globals['_GROUPSETMINCORESREQUEST']._serialized_end=9547
  _globals['_GROUPSETMINCORESRESPONSE']._serialized_start=9549
  _globals['_GROUPSETMINCORESRESPONSE']._serialized_end=9575
  _globals['_GROUPSETMAXGPUSREQUEST']._serialized_start=9577
  _globals['_GROUPSETMAXGPUSREQUEST']._serialized_end=9646
  _globals['_GROUPSETMAXGPUSRESPONSE']._serialized_start=9648
  _globals['_GROUPSETMAXGPUSRESPONSE']._serialized_end=9673
  _globals['_GROUPSETMINGPUSREQUEST']._serialized_start=9675
  _globals['_GROUPSETMINGPUSREQUEST']._serialized_end=9744
  _globals['_GROUPSETMINGPUSRESPONSE']._serialized_start=9746
  _globals['_GROUPSETMINGPUSRESPONSE']._serialized_end=9771
  _globals['_GROUPSETNAMEREQUEST']._serialized_start=9773
  _globals['_GROUPSETNAMEREQUEST']._serialized_end=9835
  _globals['_GROUPSETNAMERESPONSE']._serialized_start=9837
  _globals['_GROUPSETNAMERESPONSE']._serialized_end=9859
  _globals['_JOBADDCOMMENTREQUEST']._serialized_start=9861
  _globals['_JOBADDCOMMENTREQUEST']._serialized_end=9945
  _globals['_JOBADDCOMMENTRESPONSE']._serialized_start=9947
  _globals['_JOBADDCOMMENTRESPONSE']._serialized_end=9970
  _globals['_JOBADDRENDERPARTREQUEST']._serialized_start=9973
  _globals['_JOBADDRENDERPARTREQUEST']._serialized_end=10151
  _globals['_JOBADDRENDERPARTRESPONSE']._serialized_start=10153
  _globals['_JOBADDRENDERPARTRESPONSE']._serialized_end=10239
  _globals['_JOBADDSUBSCRIBERREQUEST']._serialized_start=10241
  _globals['_JOBADDSUBSCRIBERREQUEST']._serialized_end=10309
  _globals['_JOBADDSUBSCRIBERRESPONSE']._serialized_start=10311
  _globals['_JOBADDSUBSCRIBERRESPONSE']._serialized_end=10337
  _globals['_JOBCREATEDEPENDENCYONFRAMEREQUEST']._serialized_start=10339
  _globals['_JOBCREATEDEPENDENCYONFRAMEREQUEST']._serialized_end=10424
  _globals['_JOBCREATEDEPENDENCYONFRAMERESPONSE']._serialized_start=10426
  _globals['_JOBCREATEDEPENDENCYONFRAMERESPONSE']._serialized_end=10494
  _globals['_JOBCREATEDEPENDENCYONJOBREQUEST']._serialized_start=10496
  _globals['_JOBCREATEDEPENDENCYONJOBREQUEST']._serialized_end=10578
  _globals['_JOBCREATEDEPENDENCYONJOBRESPONSE']._serialized_start=10580
  _globals['_JOBCREATEDEPENDENCYONJOBRESPONSE']._serialized_end=10646
  _globals['_JOBCREATEDEPENDENCYONLAYERREQUEST']._serialized_start=10648
  _globals['_JOBCREATEDEPENDENCYONLAYERREQUEST']._serialized_end=10733
  _globals['_JOBCREATEDEPENDENCYONLAYERRESPONSE']._serialized_start=10735
  _globals['_JOBCREATEDEPENDENCYONLAYERRESPONSE']._serialized_end=10803
  _globals['_JOBDROPDEPENDSREQUEST']._serialized_start=10805
  _globals['_JOBDROPDEPENDSREQUEST']._serialized_end=10889
  _globals['_JOBDROPDEPENDSRESPONSE']._serialized_start=10891
  _globals['_JOBDROPDEPENDSRESPONSE']._serialized_end=10915
  _globals['_JOBEATFRAMESREQUEST']._serialized_start=10917
  _globals['_JOBEATFRAMESREQUEST']._serialized_end=11000
  _globals['_JOBEATFRAMESRESPONSE']._serialized_start=11002
  _globals['_JOBEATFRAMESRESPONSE']._serialized_end=11024
  _globals['_JOBFINDJOBREQUEST']._serialized_start=11026
  _globals['_JOBFINDJOBREQUEST']._serialized_end=11059
  _globals['_JOBFINDJOBRESPONSE']._serialized_start=11061
  _globals['_JOBFINDJOBRESPONSE']._serialized_end=11104
  _globals['_JOBGETCOMMENTSREQUEST']._serialized_start=11106
  _globals['_JOBGETCOMMENTSREQUEST']._serialized_end=11152
  _globals['_JOBGETCOMMENTSRESPONSE']._serialized_start=11154
  _globals['_JOBGETCOMMENTSRESPONSE']._serialized_end=11217
  _globals['_JOBGETCURRENTREQUEST']._serialized_start=11219
  _globals['_JOBGETCURRENTREQUEST']._serialized_end=11264
  _globals['_JOBGETCURRENTRESPONSE']._serialized_start=11266
  _globals['_JOBGETCURRENTRESPONSE']._serialized_end=11312
  _globals['_JOBGETDEPENDSREQUEST']._serialized_start=11314
  _globals['_JOBGETDEPENDSREQUEST']._serialized_end=11359
  _globals['_JOBGETDEPENDSRESPONSE']._serialized_start=11361
  _globals['_JOBGETDEPENDSRESPONSE']._serialized_end=11420
  _globals['_JOBGETFRAMESREQUEST']._serialized_start=11422
  _globals['_JOBGETFRAMESREQUEST']._serialized_end=11505
  _globals['_JOBGETFRAMESRESPONSE']._serialized_start=11507
  _globals['_JOBGETFRAMESRESPONSE']._serialized_end=11560
  _globals['_JOBGETJOBREQUEST']._serialized_start=11562
  _globals['_JOBGETJOBREQUEST']._serialized_end=11592
  _globals['_JOBGETJOBRESPONSE']._serialized_start=11594
  _globals['_JOBGETJOBRESPONSE']._serialized_end=11636
  _globals['_JOBGETJOBSREQUEST']._serialized_start=11638
  _globals['_JOBGETJOBSREQUEST']._serialized_end=11692
  _globals['_JOBGETJOBSRESPONSE']._serialized_start=11694
  _globals['_JOBGETJOBSRESPONSE']._serialized_end=11741
  _globals['_JOBGETJOBNAMESREQUEST']._serialized_start=11743
  _globals['_JOBGETJOBNAMESREQUEST']._serialized_end=11801
  _globals['_JOBGETJOBNAMESRESPONSE']._serialized_start=11803
  _globals['_JOBGETJOBNAMESRESPONSE']._serialized_end=11842
  _globals['_JOBGETLAYERSREQUEST']._serialized_start=11844
  _globals['_JOBGETLAYERSREQUEST']._serialized_end=11888
  _globals['_JOBGETLAYERSRESPONSE']._serialized_start=11890
  _globals['_JOBGETLAYERSRESPONSE']._serialized_end=11943
  _globals['_JOBGETUPDATEDFRAMESREQUEST']._serialized_start=11945
  _globals['_JOBGETUPDATEDFRAMESREQUEST']._serialized_end=12053
  _globals['_JOBGETUPDATEDFRAMESRESPONSE']._serialized_start=12055
  _globals['_JOBGETUPDATEDFRAMESRESPONSE']._serialized_end=12181
  _globals['_JOBGETWHATDEPENDSONTHISREQUEST']._serialized_start=12183
  _globals['_JOBGETWHATDEPENDSONTHISREQUEST']._serialized_end=12238
  _globals['_JOBGETWHATDEPENDSONTHISRESPONSE']._serialized_start=12240
  _globals['_JOBGETWHATDEPENDSONTHISRESPONSE']._serialized_end=12309
  _globals['_JOBGETWHATTHISDEPENDSONREQUEST']._serialized_start=12311
  _globals['_JOBGETWHATTHISDEPENDSONREQUEST']._serialized_end=12366
  _globals['_JOBGETWHATTHISDEPENDSONRESPONSE']._serialized_start=12368
  _globals['_JOBGETWHATTHISDEPENDSONRESPONSE']._serialized_end=12437
  _globals['_JOBISJOBPENDINGREQUEST']._serialized_start=12439
  _globals['_JOBISJOBPENDINGREQUEST']._serialized_end=12477
  _globals['_JOBISJOBPENDINGRESPONSE']._serialized_start=12479
  _globals['_JOBISJOBPENDINGRESPONSE']._serialized_end=12519
  _globals['_JOBKILLREQUEST']._serialized_start=12521
  _globals['_JOBKILLREQUEST']._serialized_end=12626
  _globals['_JOBKILLRESPONSE']._serialized_start=12628
  _globals['_JOBKILLRESPONSE']._serialized_end=12645
  _globals['_JOBKILLFRAMESREQUEST']._serialized_start=12648
  _globals['_JOBKILLFRAMESREQUEST']._serialized_end=12798
  _globals['_JOBKILLFRAMESRESPONSE']._serialized_start=12800
  _globals['_JOBKILLFRAMESRESPONSE']._serialized_end=12823
  _globals['_JOBLAUNCHSPECREQUEST']._serialized_start=12825
  _globals['_JOBLAUNCHSPECREQUEST']._serialized_end=12861
  _globals['_JOBLAUNCHSPECRESPONSE']._serialized_start=12863
  _globals['_JOBLAUNCHSPECRESPONSE']._serialized_end=12901
  _globals['_JOBLAUNCHSPECANDWAITREQUEST']._serialized_start=12903
  _globals['_JOBLAUNCHSPECANDWAITREQUEST']._serialized_end=12946
  _globals['_JOBLAUNCHSPECANDWAITRESPONSE']._serialized_start=12948
  _globals['_JOBLAUNCHSPECANDWAITRESPONSE']._serialized_end=13005
  _globals['_JOBMARKASWAITINGREQUEST']._serialized_start=13007
  _globals['_JOBMARKASWAITINGREQUEST']._serialized_end=13094
  _globals['_JOBMARKASWAITINGRESPONSE']._serialized_start=13096
  _globals['_JOBMARKASWAITINGRESPONSE']._serialized_end=13122
  _globals['_JOBMARKDONEFRAMESREQUEST']._serialized_start=13124
  _globals['_JOBMARKDONEFRAMESREQUEST']._serialized_end=13212
  _globals['_JOBMARKDONEFRAMESRESPONSE']._serialized_start=13214
  _globals['_JOBMARKDONEFRAMESRESPONSE']._serialized_end=13241
  _globals['_JOBPAUSEREQUEST']._serialized_start=13243
  _globals['_JOBPAUSEREQUEST']._serialized_end=13283
  _globals['_JOBPAUSERESPONSE']._serialized_start=13285
  _globals['_JOBPAUSERESPONSE']._serialized_end=13303
  _globals['_JOBREORDERFRAMESREQUEST']._serialized_start=13305
  _globals['_JOBREORDERFRAMESREQUEST']._serialized_end=13395
  _globals['_JOBREORDERFRAMESRESPONSE']._serialized_start=13397
  _globals['_JOBREORDERFRAMESRESPONSE']._serialized_end=13423
  _globals['_JOBRESUMEREQUEST']._serialized_start=13425
  _globals['_JOBRESUMEREQUEST']._serialized_end=13466
  _globals['_JOBRESUMERESPONSE']._serialized_start=13468
  _globals['_JOBRESUMERESPONSE']._serialized_end=13487
  _globals['_JOBRETRYFRAMESREQUEST']._serialized_start=13489
  _globals['_JOBRETRYFRAMESREQUEST']._serialized_end=13574
  _globals['_JOBRETRYFRAMESRESPONSE']._serialized_start=13576
  _globals['_JOBRETRYFRAMESRESPONSE']._serialized_end=13600
  _globals['_JOBRUNFILTERSREQUEST']._serialized_start=13602
  _globals['_JOBRUNFILTERSREQUEST']._serialized_end=13647
  _globals['_JOBRUNFILTERSRESPONSE']._serialized_start=13649
  _globals['_JOBRUNFILTERSRESPONSE']._serialized_end=13672
  _globals['_JOBSETAUTOEATREQUEST']._serialized_start=13674
  _globals['_JOBSETAUTOEATREQUEST']._serialized_end=13734
  _globals['_JOBSETAUTOEATRESPONSE']._serialized_start=13736
  _globals['_JOBSETAUTOEATRESPONSE']._serialized_end=13759
  _globals['_JOBSETGROUPREQUEST']._serialized_start=13761
  _globals['_JOBSETGROUPREQUEST']._serialized_end=13822
  _globals['_JOBSETGROUPRESPONSE']._serialized_start=13824
  _globals['_JOBSETGROUPRESPONSE']._serialized_end=13845
  _globals['_JOBSETMAXCORESREQUEST']._serialized_start=13847
  _globals['_JOBSETMAXCORESREQUEST']._serialized_end=13906
  _globals['_JOBSETMAXCORESRESPONSE']._serialized_start=13908
  _globals['_JOBSETMAXCORESRESPONSE']._serialized_end=13932
  _globals['_JOBSETMAXGPUSREQUEST']._serialized_start=13934
  _globals['_JOBSETMAXGPUSREQUEST']._serialized_end=13992
  _globals['_JOBSETMAXGPUSRESPONSE']._serialized_start=13994
  _globals['_JOBSETMAXGPUSRESPONSE']._serialized_end=14017
  _globals['_JOBSETMAXRETRIESREQUEST']._serialized_start=14019
  _globals['_JOBSETMAXRETRIESREQUEST']._serialized_end=14088
  _globals['_JOBSETMAXRETRIESRESPONSE']._serialized_start=14090
  _globals['_JOBSETMAXRETRIESRESPONSE']._serialized_end=14116
  _globals['_JOBSETMINCORESREQUEST']._serialized_start=14118
  _globals['_JOBSETMINCORESREQUEST']._serialized_end=14177
  _globals['_JOBSETMINCORESRESPONSE']._serialized_start=14179
  _globals['_JOBSETMINCORESRESPONSE']._serialized_end=14203
  _globals['_JOBSETMINGPUSREQUEST']._serialized_start=14205
  _globals['_JOBSETMINGPUSREQUEST']._serialized_end=14263
  _globals['_JOBSETMINGPUSRESPONSE']._serialized_start=14265
  _globals['_JOBSETMINGPUSRESPONSE']._serialized_end=14288
  _globals['_JOBSETPRIORITYREQUEST']._serialized_start=14290
  _globals['_JOBSETPRIORITYREQUEST']._serialized_end=14349
  _globals['_JOBSETPRIORITYRESPONSE']._serialized_start=14351
  _globals['_JOBSETPRIORITYRESPONSE']._serialized_end=14375
  _globals['_JOBSHUTDOWNIFCOMPLETEDREQUEST']._serialized_start=14377
  _globals['_JOBSHUTDOWNIFCOMPLETEDREQUEST']._serialized_end=14431
  _globals['_JOBSHUTDOWNIFCOMPLETEDRESPONSE']._serialized_start=14433
  _globals['_JOBSHUTDOWNIFCOMPLETEDRESPONSE']._serialized_end=14465
  _globals['_JOBSTAGGERFRAMESREQUEST']._serialized_start=14467
  _globals['_JOBSTAGGERFRAMESREQUEST']._serialized_end=14547
  _globals['_JOBSTAGGERFRAMESRESPONSE']._serialized_start=14549
  _globals['_JOBSTAGGERFRAMESRESPONSE']._serialized_end=14575
  _globals['_LAYERADDLIMITREQUEST']._serialized_start=14577
  _globals['_LAYERADDLIMITREQUEST']._serialized_end=14644
  _globals['_LAYERADDLIMITRESPONSE']._serialized_start=14646
  _globals['_LAYERADDLIMITRESPONSE']._serialized_end=14669
  _globals['_LAYERADDRENDERPARTITIONREQUEST']._serialized_start=14672
  _globals['_LAYERADDRENDERPARTITIONREQUEST']._serialized_end=14861
  _globals['_LAYERADDRENDERPARTITIONRESPONSE']._serialized_start=14863
  _globals['_LAYERADDRENDERPARTITIONRESPONSE']._serialized_end=14956
  _globals['_LAYERCREATEDEPENDONFRAMEREQUEST']._serialized_start=14958
  _globals['_LAYERCREATEDEPENDONFRAMEREQUEST']._serialized_end=15045
  _globals['_LAYERCREATEDEPENDONFRAMERESPONSE']._serialized_start=15047
  _globals['_LAYERCREATEDEPENDONFRAMERESPONSE']._serialized_end=15113
  _globals['_LAYERCREATEDEPENDONJOBREQUEST']._serialized_start=15115
  _globals['_LAYERCREATEDEPENDONJOBREQUEST']._serialized_end=15196
  _globals['_LAYERCREATEDEPENDONJOBRESPONSE']._serialized_start=15198
  _globals['_LAYERCREATEDEPENDONJOBRESPONSE']._serialized_end=15262
  _globals['_LAYERCREATEDEPENDONLAYERREQUEST']._serialized_start=15264
  _globals['_LAYERCREATEDEPENDONLAYERREQUEST']._serialized_end=15361
  _globals['_LAYERCREATEDEPENDONLAYERRESPONSE']._serialized_start=15363
  _globals['_LAYERCREATEDEPENDONLAYERRESPONSE']._serialized_end=15429
  _globals['_LAYERCREATEFRAMEBYFRAMEDEPENDREQUEST']._serialized_start=15431
  _globals['_LAYERCREATEFRAMEBYFRAMEDEPENDREQUEST']._serialized_end=15549
  _globals['_LAYERCREATEFRAMEBYFRAMEDEPENDRESPONSE']._serialized_start=15551
  _globals['_LAYERCREATEFRAMEBYFRAMEDEPENDRESPONSE']._serialized_end=15622
  _globals['_LAYERDROPDEPENDSREQUEST']._serialized_start=15624
  _globals['_LAYERDROPDEPENDSREQUEST']._serialized_end=15714
  _globals['_LAYERDROPDEPENDSRESPONSE']._serialized_start=15716
  _globals['_LAYERDROPDEPENDSRESPONSE']._serialized_end=15742
  _globals['_LAYERDROPLIMITREQUEST']._serialized_start=15744
  _globals['_LAYERDROPLIMITREQUEST']._serialized_end=15812
  _globals['_LAYERDROPLIMITRESPONSE']._serialized_start=15814
  _globals['_LAYERDROPLIMITRESPONSE']._serialized_end=15838
  _globals['_LAYEREATFRAMESREQUEST']._serialized_start=15840
  _globals['_LAYEREATFRAMESREQUEST']._serialized_end=15890
  _globals['_LAYEREATFRAMESRESPONSE']._serialized_start=15892
  _globals['_LAYEREATFRAMESRESPONSE']._serialized_end=15916
  _globals['_LAYERENABLEMEMORYOPTIMIZERREQUEST']._serialized_start=15918
  _globals['_LAYERENABLEMEMORYOPTIMIZERREQUEST']._serialized_end=15995
  _globals['_LAYERENABLEMEMORYOPTIMIZERRESPONSE']._serialized_start=15997
  _globals['_LAYERENABLEMEMORYOPTIMIZERRESPONSE']._serialized_end=16033
  _globals['_LAYERFINDLAYERREQUEST']._serialized_start=16035
  _globals['_LAYERFINDLAYERREQUEST']._serialized_end=16086
  _globals['_LAYERFINDLAYERRESPONSE']._serialized_start=16088
  _globals['_LAYERFINDLAYERRESPONSE']._serialized_end=16139
  _globals['_LAYERGETFRAMESREQUEST']._serialized_start=16141
  _globals['_LAYERGETFRAMESREQUEST']._serialized_end=16228
  _globals['_LAYERGETFRAMESRESPONSE']._serialized_start=16230
  _globals['_LAYERGETFRAMESRESPONSE']._serialized_end=16285
  _globals['_LAYERGETLAYERREQUEST']._serialized_start=16287
  _globals['_LAYERGETLAYERREQUEST']._serialized_end=16321
  _globals['_LAYERGETLAYERRESPONSE']._serialized_start=16323
  _globals['_LAYERGETLAYERRESPONSE']._serialized_end=16373
  _globals['_LAYERGETLIMITSREQUEST']._serialized_start=16375
  _globals['_LAYERGETLIMITSREQUEST']._serialized_end=16425
  _globals['_LAYERGETLIMITSRESPONSE']._serialized_start=16427
  _globals['_LAYERGETLIMITSRESPONSE']._serialized_end=16481
  _globals['_LAYERGETOUTPUTPATHSREQUEST']._serialized_start=16483
  _globals['_LAYERGETOUTPUTPATHSREQUEST']._serialized_end=16538
  _globals['_LAYERGETOUTPUTPATHSRESPONSE']._serialized_start=16540
  _globals['_LAYERGETOUTPUTPATHSRESPONSE']._serialized_end=16591
  _globals['_LAYERGETWHATDEPENDSONTHISREQUEST']._serialized_start=16593
  _globals['_LAYERGETWHATDEPENDSONTHISREQUEST']._serialized_end=16654
  _globals['_LAYERGETWHATDEPENDSONTHISRESPONSE']._serialized_start=16656
  _globals['_LAYERGETWHATDEPENDSONTHISRESPONSE']._serialized_end=16727
  _globals['_LAYERGETWHATTHISDEPENDSONREQUEST']._serialized_start=16729
  _globals['_LAYERGETWHATTHISDEPENDSONREQUEST']._serialized_end=16790
  _globals['_LAYERGETWHATTHISDEPENDSONRESPONSE']._serialized_start=16792
  _globals['_LAYERGETWHATTHISDEPENDSONRESPONSE']._serialized_end=16863
  _globals['_LAYERKILLFRAMESREQUEST']._serialized_start=16865
  _globals['_LAYERKILLFRAMESREQUEST']._serialized_end=16982
  _globals['_LAYERKILLFRAMESRESPONSE']._serialized_start=16984
  _globals['_LAYERKILLFRAMESRESPONSE']._serialized_end=17009
  _globals['_LAYERMARKDONEFRAMESREQUEST']._serialized_start=17011
  _globals['_LAYERMARKDONEFRAMESREQUEST']._serialized_end=17066
  _globals['_LAYERMARKDONEFRAMESRESPONSE']._serialized_start=17068
  _globals['_LAYERMARKDONEFRAMESRESPONSE']._serialized_end=17097
  _globals['_LAYERRETRYFRAMESREQUEST']._serialized_start=17099
  _globals['_LAYERRETRYFRAMESREQUEST']._serialized_end=17151
  _globals['_LAYERRETRYFRAMESRESPONSE']._serialized_start=17153
  _globals['_LAYERRETRYFRAMESRESPONSE']._serialized_end=17179
  _globals['_LAYERREGISTEROUTPUTPATHREQUEST']._serialized_start=17181
  _globals['_LAYERREGISTEROUTPUTPATHREQUEST']._serialized_end=17254
  _globals['_LAYERREGISTEROUTPUTPATHRESPONSE']._serialized_start=17256
  _globals['_LAYERREGISTEROUTPUTPATHRESPONSE']._serialized_end=17289
  _globals['_LAYERREORDERFRAMESREQUEST']._serialized_start=17291
  _globals['_LAYERREORDERFRAMESREQUEST']._serialized_end=17387
  _globals['_LAYERREORDERFRAMESRESPONSE']._serialized_start=17389
  _globals['_LAYERREORDERFRAMESRESPONSE']._serialized_end=17417
  _globals['_LAYERSETMAXCORESREQUEST']._serialized_start=17419
  _globals['_LAYERSETMAXCORESREQUEST']._serialized_end=17486
  _globals['_LAYERSETMAXCORESRESPONSE']._serialized_start=17488
  _globals['_LAYERSETMAXCORESRESPONSE']._serialized_end=17514
  _globals['_LAYERSETMINCORESREQUEST']._serialized_start=17516
  _globals['_LAYERSETMINCORESREQUEST']._serialized_end=17583
  _globals['_LAYERSETMINCORESRESPONSE']._serialized_start=17585
  _globals['_LAYERSETMINCORESRESPONSE']._serialized_end=17611
  _globals['_LAYERSETMINGPUREQUEST']._serialized_start=17613
  _globals['_LAYERSETMINGPUREQUEST']._serialized_end=17684
  _globals['_LAYERSETMINGPURESPONSE']._serialized_start=17686
  _globals['_LAYERSETMINGPURESPONSE']._serialized_end=17710
  _globals['_LAYERSETMAXGPUSREQUEST']._serialized_start=17712
  _globals['_LAYERSETMAXGPUSREQUEST']._serialized_end=17781
  _globals['_LAYERSETMAXGPUSRESPONSE']._serialized_start=17783
  _globals['_LAYERSETMAXGPUSRESPONSE']._serialized_end=17808
  _globals['_LAYERSETMINGPUSREQUEST']._serialized_start=17810
  _globals['_LAYERSETMINGPUSREQUEST']._serialized_end=17879
  _globals['_LAYERSETMINGPUSRESPONSE']._serialized_start=17881
  _globals['_LAYERSETMINGPUSRESPONSE']._serialized_end=17906
  _globals['_LAYERSETMINGPUMEMORYREQUEST']._serialized_start=17908
  _globals['_LAYERSETMINGPUMEMORYREQUEST']._serialized_end=17984
  _globals['_LAYERSETMINGPUMEMORYRESPONSE']._serialized_start=17986
  _globals['_LAYERSETMINGPUMEMORYRESPONSE']._serialized_end=18016
  _globals['_LAYERSETMINMEMORYREQUEST']._serialized_start=18018
  _globals['_LAYERSETMINMEMORYREQUEST']._serialized_end=18087
  _globals['_LAYERSETMINMEMORYRESPONSE']._serialized_start=18089
  _globals['_LAYERSETMINMEMORYRESPONSE']._serialized_end=18116
  _globals['_LAYERSETTAGSREQUEST']._serialized_start=18118
  _globals['_LAYERSETTAGSREQUEST']._serialized_end=18180
  _globals['_LAYERSETTAGSRESPONSE']._serialized_start=18182
  _globals['_LAYERSETTAGSRESPONSE']._serialized_end=18204
  _globals['_LAYERSETTHREADABLEREQUEST']._serialized_start=18206
  _globals['_LAYERSETTHREADABLEREQUEST']._serialized_end=18280
  _globals['_LAYERSETTHREADABLERESPONSE']._serialized_start=18282
  _globals['_LAYERSETTHREADABLERESPONSE']._serialized_end=18310
  _globals['_LAYERSETTIMEOUTREQUEST']._serialized_start=18312
  _globals['_LAYERSETTIMEOUTREQUEST']._serialized_end=18380
  _globals['_LAYERSETTIMEOUTRESPONSE']._serialized_start=18382
  _globals['_LAYERSETTIMEOUTRESPONSE']._serialized_end=18407
  _globals['_LAYERSETTIMEOUTLLUREQUEST']._serialized_start=18409
  _globals['_LAYERSETTIMEOUTLLUREQUEST']._serialized_end=18484
  _globals['_LAYERSETTIMEOUTLLURESPONSE']._serialized_start=18486
  _globals['_LAYERSETTIMEOUTLLURESPONSE']._serialized_end=18514
  _globals['_LAYERSTAGGERFRAMESREQUEST']._serialized_start=18516
  _globals['_LAYERSTAGGERFRAMESREQUEST']._serialized_end=18602
  _globals['_LAYERSTAGGERFRAMESRESPONSE']._serialized_start=18604
  _globals['_LAYERSTAGGERFRAMESRESPONSE']._serialized_end=18632
  _globals['_FRAMESTATEDISPLAYOVERRIDEREQUEST']._serialized_start=18634
  _globals['_FRAMESTATEDISPLAYOVERRIDEREQUEST']._serialized_end=18745
  _globals['_FRAMESTATEDISPLAYOVERRIDERESPONSE']._serialized_start=18747
  _globals['_FRAMESTATEDISPLAYOVERRIDERESPONSE']._serialized_end=18782
  _globals['_GETFRAMESTATEDISPLAYOVERRIDESREQUEST']._serialized_start=18784
  _globals['_GETFRAMESTATEDISPLAYOVERRIDESREQUEST']._serialized_end=18849
  _globals['_GETFRAMESTATEDISPLAYOVERRIDESRESPONSE']._serialized_start=18851
  _globals['_GETFRAMESTATEDISPLAYOVERRIDESRESPONSE']._serialized_end=18944
  _globals['_FRAMEINTERFACE']._serialized_start=19379
  _globals['_FRAMEINTERFACE']._serialized_end=20965
  _globals['_GROUPINTERFACE']._serialized_start=20968
  _globals['_GROUPINTERFACE']._serialized_end=22548
  _globals['_JOBINTERFACE']._serialized_start=22551
  _globals['_JOBINTERFACE']._serialized_end=25708
  _globals['_LAYERINTERFACE']._serialized_start=25711
  _globals['_LAYERINTERFACE']._serialized_end=28537
# @@protoc_insertion_point(module_scope)


# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import service_pb2 as service__pb2


class ServiceInterfaceStub(object):
    """Interface for managing Service objects

    -------- Services --------]

    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateService = channel.unary_unary(
                '/service.ServiceInterface/CreateService',
                request_serializer=service__pb2.ServiceCreateServiceRequest.SerializeToString,
                response_deserializer=service__pb2.ServiceCreateServiceResponse.FromString,
                )
        self.Delete = channel.unary_unary(
                '/service.ServiceInterface/Delete',
                request_serializer=service__pb2.ServiceDeleteRequest.SerializeToString,
                response_deserializer=service__pb2.ServiceDeleteResponse.FromString,
                )
        self.GetDefaultServices = channel.unary_unary(
                '/service.ServiceInterface/GetDefaultServices',
                request_serializer=service__pb2.ServiceGetDefaultServicesRequest.SerializeToString,
                response_deserializer=service__pb2.ServiceGetDefaultServicesResponse.FromString,
                )
        self.GetService = channel.unary_unary(
                '/service.ServiceInterface/GetService',
                request_serializer=service__pb2.ServiceGetServiceRequest.SerializeToString,
                response_deserializer=service__pb2.ServiceGetServiceResponse.FromString,
                )
        self.Update = channel.unary_unary(
                '/service.ServiceInterface/Update',
                request_serializer=service__pb2.ServiceUpdateRequest.SerializeToString,
                response_deserializer=service__pb2.ServiceUpdateResponse.FromString,
                )


class ServiceInterfaceServicer(object):
    """Interface for managing Service objects

    -------- Services --------]

    """

    def CreateService(self, request, context):
        """Create a new service.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Delete the provided service
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDefaultServices(self, request, context):
        """Return a the list of default services.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetService(self, request, context):
        """Return the given service using its name or unique id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Update the provided service
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ServiceInterfaceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateService': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateService,
                    request_deserializer=service__pb2.ServiceCreateServiceRequest.FromString,
                    response_serializer=service__pb2.ServiceCreateServiceResponse.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=service__pb2.ServiceDeleteRequest.FromString,
                    response_serializer=service__pb2.ServiceDeleteResponse.SerializeToString,
            ),
            'GetDefaultServices': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDefaultServices,
                    request_deserializer=service__pb2.ServiceGetDefaultServicesRequest.FromString,
                    response_serializer=service__pb2.ServiceGetDefaultServicesResponse.SerializeToString,
            ),
            'GetService': grpc.unary_unary_rpc_method_handler(
                    servicer.GetService,
                    request_deserializer=service__pb2.ServiceGetServiceRequest.FromString,
                    response_serializer=service__pb2.ServiceGetServiceResponse.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=service__pb2.ServiceUpdateRequest.FromString,
                    response_serializer=service__pb2.ServiceUpdateResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'service.ServiceInterface', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ServiceInterface(object):
    """Interface for managing Service objects

    -------- Services --------]

    """

    @staticmethod
    def CreateService(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/service.ServiceInterface/CreateService',
            service__pb2.ServiceCreateServiceRequest.SerializeToString,
            service__pb2.ServiceCreateServiceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/service.ServiceInterface/Delete',
            service__pb2.ServiceDeleteRequest.SerializeToString,
            service__pb2.ServiceDeleteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDefaultServices(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/service.ServiceInterface/GetDefaultServices',
            service__pb2.ServiceGetDefaultServicesRequest.SerializeToString,
            service__pb2.ServiceGetDefaultServicesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetService(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/service.ServiceInterface/GetService',
            service__pb2.ServiceGetServiceRequest.SerializeToString,
            service__pb2.ServiceGetServiceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/service.ServiceInterface/Update',
            service__pb2.ServiceUpdateRequest.SerializeToString,
            service__pb2.ServiceUpdateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class ServiceOverrideInterfaceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Delete = channel.unary_unary(
                '/service.ServiceOverrideInterface/Delete',
                request_serializer=service__pb2.ServiceOverrideDeleteRequest.SerializeToString,
                response_deserializer=service__pb2.ServiceOverrideDeleteResponse.FromString,
                )
        self.Update = channel.unary_unary(
                '/service.ServiceOverrideInterface/Update',
                request_serializer=service__pb2.ServiceOverrideUpdateRequest.SerializeToString,
                response_deserializer=service__pb2.ServiceOverrideUpdateResponse.FromString,
                )


class ServiceOverrideInterfaceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Delete(self, request, context):
        """Delete the service override
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Update this service override
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ServiceOverrideInterfaceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=service__pb2.ServiceOverrideDeleteRequest.FromString,
                    response_serializer=service__pb2.ServiceOverrideDeleteResponse.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=service__pb2.ServiceOverrideUpdateRequest.FromString,
                    response_serializer=service__pb2.ServiceOverrideUpdateResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'service.ServiceOverrideInterface', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ServiceOverrideInterface(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/service.ServiceOverrideInterface/Delete',
            service__pb2.ServiceOverrideDeleteRequest.SerializeToString,
            service__pb2.ServiceOverrideDeleteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/service.ServiceOverrideInterface/Update',
            service__pb2.ServiceOverrideUpdateRequest.SerializeToString,
            service__pb2.ServiceOverrideUpdateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)